@@ -25,13 +25,14 @@ import xml.dom.minidom
 # SET VERSION
 # -----------
 
-version = '5.3.0'
+version = '5.4.1'
 nightbuild = ''
 
 
 # SET CONFIG FOLDER
 # -----------------
 
+# set config folder for MAC OS X
 if sys.platform == 'darwin':
     confdir = 'configs'
     support = os.path.expanduser("~/Library/Application Support/")
@@ -42,6 +43,18 @@ if sys.platform == 'darwin':
     if os.path.exists(userconf):
         confdir = userconf
 
+# set config folder for Linux
+elif sys.platform.startswith('linux') or sys.platform.startswith('freebsd'):
+    confdir = 'configs'
+    home = os.path.expanduser("~")
+    userconf = os.path.join(home,'.mmass')
+    if os.path.exists(home) and not os.path.exists(userconf):
+        try: os.mkdir(userconf)
+        except: pass
+    if os.path.exists(userconf):
+        confdir = userconf
+
+# set config folder for Windows
 else:
     confdir = os.path.sep
     for folder in os.path.dirname(os.path.realpath(__file__)).split(os.path.sep)[:-1]:
@@ -160,7 +173,7 @@ spectrum={
     'showTicks': 1,
     'showDataPoints': 1,
     'showCursorImage': 1,
-    'barHeight': 7,
+    'posBarSize': 7,
     'gelHeight': 19,
     'autoscale': 1,
     'normalize': 0,
@@ -338,22 +351,23 @@ massToFormula={
     'SCMax': 3,
     'RDBEMin': -1,
     'RDBEMax': 40,
-    'PubChemScript': 'http://pubchem.ncbi.nlm.nih.gov/search/search.cgi',
+    'PubChemScript':'http://pubchem.ncbi.nlm.nih.gov/search/search.cgi',
     'ChemSpiderScript': 'http://www.chemspider.com/Search.aspx',
     'METLINScript': 'http://metlin.scripps.edu/metabo_list_adv.php',
-    'HMDBScript': 'http://www.hmdb.ca/search/search',
+    'HMDBScript': 'http://www.hmdb.ca/search',
     'LipidMAPSScript': 'http://www.lipidmaps.org/data/structure/LMSDSearch.php',
 }
 
 massDefectPlot={
-    'xAxis': 'm/z',
-    'yAxis': 'Mass Defect',
-    'groupFormula': '',
+    'xAxis': 'mz',
+    'yAxis': 'standard',
     'nominalMass': 'floor',
+    'kendrickFormula': 'CH2',
     'relIntCutoff': 0.0,
-    'ignoreCharge': 1,
     'removeIsotopes': 0,
+    'ignoreCharge': 1,
     'showNotations': 0,
+    'showAllDocuments': 0,
 }
 
 compoundsSearch={
@@ -946,7 +960,7 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="showAllLabels" value="%d" type="int" />\n' % (bool(spectrum['showAllLabels']))
     buff += '    <param name="showTicks" value="%d" type="int" />\n' % (bool(spectrum['showTicks']))
     buff += '    <param name="showCursorImage" value="%d" type="int" />\n' % (bool(spectrum['showCursorImage']))
-    buff += '    <param name="barHeight" value="%d" type="int" />\n' % (spectrum['barHeight'])
+    buff += '    <param name="posBarSize" value="%d" type="int" />\n' % (spectrum['posBarSize'])
     buff += '    <param name="gelHeight" value="%d" type="int" />\n' % (spectrum['gelHeight'])
     buff += '    <param name="autoscale" value="%d" type="int" />\n' % (bool(spectrum['autoscale']))
     buff += '    <param name="overlapLabels" value="%d" type="int" />\n' % (bool(spectrum['overlapLabels']))
@@ -1106,22 +1120,16 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="SCMax" value="%f" type="float" />\n' % (massToFormula['SCMax'])
     buff += '    <param name="RDBEMin" value="%f" type="float" />\n' % (massToFormula['RDBEMin'])
     buff += '    <param name="RDBEMax" value="%f" type="float" />\n' % (massToFormula['RDBEMax'])
-    buff += '    <param name="PubChemScript" value="%s" type="unicode" />\n' % (_escape(massToFormula['PubChemScript']))
-    buff += '    <param name="ChemSpiderScript" value="%s" type="unicode" />\n' % (_escape(massToFormula['ChemSpiderScript']))
-    buff += '    <param name="METLINScript" value="%s" type="unicode" />\n' % (_escape(massToFormula['METLINScript']))
-    buff += '    <param name="HMDBScript" value="%s" type="unicode" />\n' % (_escape(massToFormula['HMDBScript']))
-    buff += '    <param name="LipidMAPSScript" value="%s" type="unicode" />\n' % (_escape(massToFormula['LipidMAPSScript']))
     buff += '  </massToFormula>\n\n'
     
     # mass defect plot
     buff += '  <massDefectPlot>\n'
-    buff += '    <param name="xAxis" value="%s" type="str" />\n' % (massDefectPlot['xAxis'])
     buff += '    <param name="yAxis" value="%s" type="str" />\n' % (massDefectPlot['yAxis'])
-    buff += '    <param name="groupFormula" value="%s" type="str" />\n' % (massDefectPlot['groupFormula'])
     buff += '    <param name="nominalMass" value="%s" type="str" />\n' % (massDefectPlot['nominalMass'])
+    buff += '    <param name="kendrickFormula" value="%s" type="str" />\n' % (massDefectPlot['kendrickFormula'])
     buff += '    <param name="relIntCutoff" value="%f" type="float" />\n' % (massDefectPlot['relIntCutoff'])
-    buff += '    <param name="ignoreCharge" value="%d" type="int" />\n' % (bool(massDefectPlot['ignoreCharge']))
     buff += '    <param name="removeIsotopes" value="%d" type="int" />\n' % (bool(massDefectPlot['removeIsotopes']))
+    buff += '    <param name="ignoreCharge" value="%d" type="int" />\n' % (bool(massDefectPlot['ignoreCharge']))
     buff += '    <param name="showNotations" value="%d" type="int" />\n' % (bool(massDefectPlot['showNotations']))
     buff += '  </massDefectPlot>\n\n'
     
