@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -73,7 +73,7 @@ class dlgModificationsEditor(wx.Dialog):
         """Make list for items."""
         
         # init list
-        self.itemsList = mwx.sortListCtrl(self, -1, size=(771, 250), style=mwx.LISTCTRL_STYLE_MULTI)
+        self.itemsList = mwx.sortListCtrl(self, -1, size=(841, 250), style=mwx.LISTCTRL_STYLE_MULTI)
         self.itemsList.SetFont(wx.SMALL_FONT)
         self.itemsList.setAltColour(mwx.LISTCTRL_ALTCOLOUR)
         
@@ -91,7 +91,7 @@ class dlgModificationsEditor(wx.Dialog):
         self.itemsList.InsertColumn(7, "description", wx.LIST_FORMAT_LEFT)
         
         # set column widths
-        for col, width in enumerate((110,100,60,90,90,100,50,150)):
+        for col, width in enumerate((110,100,60,90,90,100,50,220)):
             self.itemsList.SetColumnWidth(col, width)
     # ----
     
@@ -103,17 +103,17 @@ class dlgModificationsEditor(wx.Dialog):
         
         # make elements
         itemName_label = wx.StaticText(self, -1, "Name:")
-        self.itemName_value = wx.TextCtrl(self, -1, "", size=(200, -1))
+        self.itemName_value = wx.TextCtrl(self, -1, "", size=(250, -1))
         
         itemDescription_label = wx.StaticText(self, -1, "Description:")
-        self.itemDescription_value = wx.TextCtrl(self, -1, "", size=(200, -1))
+        self.itemDescription_value = wx.TextCtrl(self, -1, "", size=(250, -1))
         
         itemAminoSpecifity_label = wx.StaticText(self, -1, "Amino specifity:")
-        self.itemAminoSpecifity_value = wx.TextCtrl(self, -1, "", size=(200, -1))
+        self.itemAminoSpecifity_value = wx.TextCtrl(self, -1, "", size=(250, -1))
         
-        itemTermSpecifity_label = wx.StaticText(self, -1, "Term specifity:")
-        self.itemTermSpecifity_combo = wx.ComboBox(self, -1, choices=['None','N-term','C-term'], size=(200, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.itemTermSpecifity_combo.SetValue('None')
+        itemTermSpecifity_label = wx.StaticText(self, -1, "Terminal specifity:")
+        self.itemTermSpecifity_choice = wx.Choice(self, -1, choices=['None','N-terminus','C-terminus'], size=(250, mwx.CHOICE_HEIGHT))
+        self.itemTermSpecifity_choice.SetStringSelection('None')
         
         itemGainFormula_label = wx.StaticText(self, -1, "Gain formula:")
         self.itemGainFormula_value = mwx.formulaCtrl(self, -1, "", size=(150, -1))
@@ -150,7 +150,7 @@ class dlgModificationsEditor(wx.Dialog):
         grid.Add(itemAminoSpecifity_label, (2,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         grid.Add(self.itemAminoSpecifity_value, (2,1), flag=wx.ALIGN_CENTER_VERTICAL)
         grid.Add(itemTermSpecifity_label, (3,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        grid.Add(self.itemTermSpecifity_combo, (3,1), flag=wx.ALIGN_CENTER_VERTICAL)
+        grid.Add(self.itemTermSpecifity_choice, (3,1), flag=wx.ALIGN_CENTER_VERTICAL)
         
         grid.Add(itemGainFormula_label, (0,3), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         grid.Add(self.itemGainFormula_value, (0,4), flag=wx.ALIGN_CENTER_VERTICAL)
@@ -186,11 +186,11 @@ class dlgModificationsEditor(wx.Dialog):
         self.itemLossFormula_value.SetValue(mod.lossFormula)
         
         if mod.termSpecifity == 'C':
-            self.itemTermSpecifity_combo.SetValue('C-term')
+            self.itemTermSpecifity_choice.SetStringSelection('C-terminus')
         elif mod.termSpecifity == 'N':
-            self.itemTermSpecifity_combo.SetValue('N-term')
+            self.itemTermSpecifity_choice.SetStringSelection('N-terminus')
         else:
-            self.itemTermSpecifity_combo.SetValue('None')
+            self.itemTermSpecifity_choice.SetStringSelection('None')
     # ----
     
     
@@ -352,7 +352,7 @@ class dlgModificationsEditor(wx.Dialog):
         self.itemLossFormula_value.SetValue('')
         self.itemMoMass_value.SetValue('')
         self.itemAvMass_value.SetValue('')
-        self.itemTermSpecifity_combo.SetValue('None')
+        self.itemTermSpecifity_choice.SetStringSelection('None')
     # ----
     
     
@@ -363,16 +363,16 @@ class dlgModificationsEditor(wx.Dialog):
         name = self.itemName_value.GetValue()
         description = self.itemDescription_value.GetValue()
         aminoSpecifity = self.itemAminoSpecifity_value.GetValue()
-        termSpecifity = self.itemTermSpecifity_combo.GetValue()
+        termSpecifity = self.itemTermSpecifity_choice.GetStringSelection()
         gainFormula = self.itemGainFormula_value.GetValue()
         lossFormula = self.itemLossFormula_value.GetValue()
         
         # term specifity
         if termSpecifity == 'None':
             termSpecifity = ''
-        elif termSpecifity == 'N-term':
+        elif termSpecifity == 'N-terminus':
             termSpecifity = 'N'
-        elif termSpecifity == 'C-term':
+        elif termSpecifity == 'C-terminus':
             termSpecifity = 'C'
         
         # check values
