@@ -139,23 +139,24 @@ class dlgSelectScans(wx.Dialog):
         self.chromCanvas.setProperties(showGrid=True)
         self.chromCanvas.setProperties(showMinorTicks=config.spectrum['showMinorTicks'])
         self.chromCanvas.setProperties(showLegend=True)
-        self.chromCanvas.setProperties(showPosBar=True)
-        self.chromCanvas.setProperties(showIntBar=True)
-        self.chromCanvas.setProperties(posBarHeight=6)
-        self.chromCanvas.setProperties(intBarHeight=6)
+        self.chromCanvas.setProperties(showXPosBar=True)
+        self.chromCanvas.setProperties(showYPosBar=True)
+        self.chromCanvas.setProperties(posBarSize=6)
         self.chromCanvas.setProperties(showGel=False)
         self.chromCanvas.setProperties(checkLimits=True)
         self.chromCanvas.setProperties(autoScaleY=True)
+        self.chromCanvas.setProperties(zoomAxis='x')
         self.chromCanvas.setProperties(xPosDigits=2)
         self.chromCanvas.setProperties(yPosDigits=2)
         self.chromCanvas.setProperties(reverseScrolling=config.main['reverseScrolling'])
         self.chromCanvas.setProperties(reverseDrawing=True)
+        self.chromCanvas.setLMBFunction('xDistance')
         self.chromCanvas.setMFunction('cross')
         
         axisFont = wx.Font(config.spectrum['axisFontSize'], wx.SWISS, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, 0)
         self.chromCanvas.setProperties(axisFont=axisFont)
         
-        self.chromCanvas.canvas.Bind(wx.EVT_LEFT_UP, self.onCanvasLMU)
+        self.chromCanvas.Bind(wx.EVT_LEFT_UP, self.onCanvasLMU)
         
         self.chromCanvas.draw(mspy.plot.container([]))
     # ----
