@@ -26,6 +26,7 @@ import xml.dom.minidom
 import os.path
 import re
 import numpy
+import wx
 
 # load modules
 import images
@@ -57,6 +58,7 @@ class document():
         self.sequences = []
         
         self.colour = (0,0,255)
+        self.style = wx.SOLID
         self.dirty = False
         self.visible = True
         self.flipped = False
