@@ -97,6 +97,7 @@ presets = {
                 'forceGroupWindow': 0,
             },
             'batch':{
+                'swap': 0,
                 'math': 0,
                 'crop': 0,
                 'baseline': 0,
@@ -148,6 +149,7 @@ presets = {
                 'forceGroupWindow': 0,
             },
             'batch':{
+                'swap': 0,
                 'math': 0,
                 'crop': 0,
                 'baseline': 0,
@@ -199,6 +201,7 @@ presets = {
                 'forceGroupWindow': 0,
             },
             'batch':{
+                'swap': 0,
                 'math': 0,
                 'crop': 0,
                 'baseline': 0,
@@ -250,6 +253,7 @@ presets = {
                 'forceGroupWindow': 0,
             },
             'batch':{
+                'swap': 0,
                 'math': 0,
                 'crop': 0,
                 'baseline': 0,
@@ -301,6 +305,7 @@ presets = {
                 'forceGroupWindow': 0,
             },
             'batch':{
+                'swap': 0,
                 'math': 0,
                 'crop': 0,
                 'baseline': 0,
@@ -352,6 +357,7 @@ presets = {
                 'forceGroupWindow': 0,
             },
             'batch':{
+                'swap': 0,
                 'math': 0,
                 'crop': 0,
                 'baseline': 0,
@@ -854,6 +860,7 @@ def savePresets(path=os.path.join(config.confdir, 'presets.xml')):
         buff += '        <param name="forceGroupWindow" value="%d" type="int" />\n' % (bool(item['deconvolution']['forceGroupWindow']))
         buff += '      </deconvolution>\n'
         buff += '      <batch>\n'
+        buff += '        <param name="swap" value="%d" type="int" />\n' % (bool(item['batch']['swap']))
         buff += '        <param name="math" value="%d" type="int" />\n' % (bool(item['batch']['math']))
         buff += '        <param name="crop" value="%d" type="int" />\n' % (bool(item['batch']['crop']))
         buff += '        <param name="baseline" value="%d" type="int" />\n' % (bool(item['batch']['baseline']))
