@@ -259,8 +259,8 @@ class panelCalibration(wx.MiniFrame):
         self.errorCanvas.setProperties(showGrid=True)
         self.errorCanvas.setProperties(showMinorTicks=False)
         self.errorCanvas.setProperties(showLegend=True)
-        self.errorCanvas.setProperties(showPosBar=True)
-        self.errorCanvas.setProperties(posBarHeight=6)
+        self.errorCanvas.setProperties(showXPosBar=True)
+        self.errorCanvas.setProperties(posBarSize=6)
         self.errorCanvas.setProperties(showGel=False)
         self.errorCanvas.setProperties(zoomAxis='x')
         self.errorCanvas.setProperties(checkLimits=True)
