@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -110,23 +110,20 @@ class panelCompoundsSearch(wx.MiniFrame):
         choices = libs.compounds.keys()
         choices.sort()
         choices.insert(0,'Compounds lists')
-        self.compounds_combo = wx.ComboBox(panel, -1, choices=choices, size=(250, mwx.SMALL_COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.compounds_combo.Select(0)
-        self.compounds_combo.Bind(wx.EVT_COMBOBOX, self.onGenerate)
+        self.compounds_choice = wx.Choice(panel, -1, choices=choices, size=(250, mwx.SMALL_CHOICE_HEIGHT))
+        self.compounds_choice.Select(0)
+        self.compounds_choice.Bind(wx.EVT_CHOICE, self.onGenerate)
         
         self.formula_value = wx.TextCtrl(panel, -1, "", size=(270,-1))
         
         # make buttons
         self.generate_butt = wx.Button(panel, -1, "Generate", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.generate_butt.SetFont(wx.SMALL_FONT)
         self.generate_butt.Bind(wx.EVT_BUTTON, self.onGenerate)
         
         self.match_butt = wx.Button(panel, -1, "Match", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.match_butt.SetFont(wx.SMALL_FONT)
         self.match_butt.Bind(wx.EVT_BUTTON, self.onMatch)
         
         self.annotate_butt = wx.Button(panel, -1, "Annotate", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.annotate_butt.SetFont(wx.SMALL_FONT)
         self.annotate_butt.Bind(wx.EVT_BUTTON, self.onAnnotate)
         
         # pack elements
@@ -136,7 +133,7 @@ class panelCompoundsSearch(wx.MiniFrame):
         self.toolbar.Add(self.formula_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
         self.toolbar.AddSpacer(20)
         self.toolbar.Add(self.tool_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
-        self.toolbar.Add(self.compounds_combo, 0, wx.ALIGN_CENTER_VERTICAL)
+        self.toolbar.Add(self.compounds_choice, 0, wx.ALIGN_CENTER_VERTICAL)
         self.toolbar.Add(self.formula_value, 0, wx.ALIGN_CENTER_VERTICAL)
         self.toolbar.AddStretchSpacer()
         self.toolbar.AddSpacer(20)
@@ -173,48 +170,48 @@ class panelCompoundsSearch(wx.MiniFrame):
         
         self.massTypeAv_radio = wx.RadioButton(panel, -1, "Av")
         self.massTypeAv_radio.SetFont(wx.SMALL_FONT)
-        self.massTypeAv_radio.SetValue(config.compounds['massType'])
+        self.massTypeAv_radio.SetValue(config.compoundsSearch['massType'])
         
         maxCharge_label = wx.StaticText(panel, -1, "Max charge:")
         maxCharge_label.SetFont(wx.SMALL_FONT)
         
-        self.maxCharge_value = wx.TextCtrl(panel, -1, str(config.compounds['maxCharge']), size=(30, mwx.SMALL_TEXTCTRL_HEIGHT), validator=mwx.validator('int'))
+        self.maxCharge_value = wx.TextCtrl(panel, -1, str(config.compoundsSearch['maxCharge']), size=(30, mwx.SMALL_TEXTCTRL_HEIGHT), validator=mwx.validator('int'))
         self.maxCharge_value.SetFont(wx.SMALL_FONT)
         
         self.radicals_check = wx.CheckBox(panel, -1, "M*")
         self.radicals_check.SetFont(wx.SMALL_FONT)
-        self.radicals_check.SetValue(config.compounds['radicals'])
+        self.radicals_check.SetValue(config.compoundsSearch['radicals'])
         
         adducts_label = wx.StaticText(panel, -1, "Adducts:")
         adducts_label.SetFont(wx.SMALL_FONT)
         
         self.adductNa_check = wx.CheckBox(panel, -1, "Na")
         self.adductNa_check.SetFont(wx.SMALL_FONT)
-        self.adductNa_check.SetValue(config.compounds['adducts'].count('Na'))
+        self.adductNa_check.SetValue(config.compoundsSearch['adducts'].count('Na'))
         
         self.adductK_check = wx.CheckBox(panel, -1, "K")
         self.adductK_check.SetFont(wx.SMALL_FONT)
-        self.adductK_check.SetValue(config.compounds['adducts'].count('K'))
+        self.adductK_check.SetValue(config.compoundsSearch['adducts'].count('K'))
         
         self.adductLi_check = wx.CheckBox(panel, -1, "Li")
         self.adductLi_check.SetFont(wx.SMALL_FONT)
-        self.adductLi_check.SetValue(config.compounds['adducts'].count('Li'))
+        self.adductLi_check.SetValue(config.compoundsSearch['adducts'].count('Li'))
         
         self.adductNH4_check = wx.CheckBox(panel, -1, "NH4")
         self.adductNH4_check.SetFont(wx.SMALL_FONT)
-        self.adductNH4_check.SetValue(config.compounds['adducts'].count('NH4'))
+        self.adductNH4_check.SetValue(config.compoundsSearch['adducts'].count('NH4'))
         
         self.adductH2O_check = wx.CheckBox(panel, -1, "-H2O")
         self.adductH2O_check.SetFont(wx.SMALL_FONT)
-        self.adductH2O_check.SetValue(config.compounds['adducts'].count('-H2O'))
+        self.adductH2O_check.SetValue(config.compoundsSearch['adducts'].count('-H2O'))
         
         self.adductACN_check = wx.CheckBox(panel, -1, "ACN")
         self.adductACN_check.SetFont(wx.SMALL_FONT)
-        self.adductACN_check.SetValue(config.compounds['adducts'].count('ACN'))
+        self.adductACN_check.SetValue(config.compoundsSearch['adducts'].count('ACN'))
         
         self.adductMeOH_check = wx.CheckBox(panel, -1, "MeOH")
         self.adductMeOH_check.SetFont(wx.SMALL_FONT)
-        self.adductMeOH_check.SetValue(config.compounds['adducts'].count('MeOH'))
+        self.adductMeOH_check.SetValue(config.compoundsSearch['adducts'].count('MeOH'))
         
         # pack elements
         sizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -424,7 +421,7 @@ class panelCompoundsSearch(wx.MiniFrame):
             wx.Bell()
             return
         
-        # send data to masscalc
+        # send data to Mass Calculator tool
         if radical == 'radical':
             self.parent.onToolsMassCalculator(formula=formula, charge=charge, agentFormula='e', agentCharge=-1)
         else:
@@ -552,7 +549,7 @@ class panelCompoundsSearch(wx.MiniFrame):
         
         # get compounds from selected group or formula
         if self.currentTool == 'compounds':
-            group = self.compounds_combo.GetValue()
+            group = self.compounds_choice.GetStringSelection()
             if group and group in libs.compounds:
                 compounds = libs.compounds[group]
         else:
@@ -653,7 +650,7 @@ class panelCompoundsSearch(wx.MiniFrame):
         self.currentDocument.backup(('annotations'))
         self.currentDocument.annotations += annotations
         self.currentDocument.sortAnnotations()
-        self.parent.onDocumentChanged(('annotations'))
+        self.parent.onDocumentChanged(items=('annotations'))
     # ----
     
     
@@ -673,28 +670,28 @@ class panelCompoundsSearch(wx.MiniFrame):
         
         # try to get values
         try:
-            config.compounds['massType'] = 0
+            config.compoundsSearch['massType'] = 0
             if self.massTypeAv_radio.GetValue():
-                config.compounds['massType'] = 1
+                config.compoundsSearch['massType'] = 1
             
-            config.compounds['maxCharge'] = int(self.maxCharge_value.GetValue())
-            config.compounds['radicals'] = int(self.radicals_check.GetValue())
+            config.compoundsSearch['maxCharge'] = int(self.maxCharge_value.GetValue())
+            config.compoundsSearch['radicals'] = int(self.radicals_check.GetValue())
             
-            config.compounds['adducts'] = []
+            config.compoundsSearch['adducts'] = []
             if self.adductNa_check.GetValue():
-                config.compounds['adducts'].append('Na')
+                config.compoundsSearch['adducts'].append('Na')
             if self.adductK_check.GetValue():
-                config.compounds['adducts'].append('K')
+                config.compoundsSearch['adducts'].append('K')
             if self.adductLi_check.GetValue():
-                config.compounds['adducts'].append('Li')
+                config.compoundsSearch['adducts'].append('Li')
             if self.adductNH4_check.GetValue():
-                config.compounds['adducts'].append('NH4')
+                config.compoundsSearch['adducts'].append('NH4')
             if self.adductH2O_check.GetValue():
-                config.compounds['adducts'].append('-H2O')
+                config.compoundsSearch['adducts'].append('-H2O')
             if self.adductACN_check.GetValue():
-                config.compounds['adducts'].append('ACN')
+                config.compoundsSearch['adducts'].append('ACN')
             if self.adductMeOH_check.GetValue():
-                config.compounds['adducts'].append('MeOH')
+                config.compoundsSearch['adducts'].append('MeOH')
             
             return True
             
@@ -808,9 +805,9 @@ class panelCompoundsSearch(wx.MiniFrame):
             
             # get max charge and polarity
             polarity = 1
-            if config.compounds['maxCharge'] < 0:
+            if config.compoundsSearch['maxCharge'] < 0:
                 polarity = -1
-            maxCharge = abs(config.compounds['maxCharge'])+1
+            maxCharge = abs(config.compoundsSearch['maxCharge'])+1
             
             # generate compounds ions
             self.currentCompounds = []
@@ -826,18 +823,18 @@ class panelCompoundsSearch(wx.MiniFrame):
                     # 0 name, 1 m/z, 2 z, 3 adduct, 4 formula, 5 error, 6 matches
                     
                     # main ion
-                    mz = compound.mz(z*polarity)[config.compounds['massType']]
+                    mz = compound.mz(z*polarity)[config.compoundsSearch['massType']]
                     self.currentCompounds.append([name, mz, z*polarity, None, compound.expression, None, []])
                     
                     # radicals
-                    if config.compounds['radicals']:
-                        mz = compound.mz(z*polarity, agentFormula='e', agentCharge=-1)[config.compounds['massType']]
+                    if config.compoundsSearch['radicals']:
+                        mz = compound.mz(z*polarity, agentFormula='e', agentCharge=-1)[config.compoundsSearch['massType']]
                         self.currentCompounds.append([name, mz, z*polarity, 'radical', compound.expression, None, []])
                     
                     mspy.CHECK_FORCE_QUIT()
                     
                     # add adducts
-                    for item in config.compounds['adducts']:
+                    for item in config.compoundsSearch['adducts']:
                         
                         if item in ('Na', 'K', 'Li', 'NH4', 'ACN', 'MeOH'):
                             formula = '%s(%s)(H-1)' % (compound.expression, adducts[item])
@@ -846,16 +843,16 @@ class panelCompoundsSearch(wx.MiniFrame):
                         
                         formula = mspy.compound(formula)
                         if formula.isvalid():
-                            mz = formula.mz(z*polarity)[config.compounds['massType']]
+                            mz = formula.mz(z*polarity)[config.compoundsSearch['massType']]
                             self.currentCompounds.append([name, mz, z*polarity, item, formula.expression, None, []])
                     
                     mspy.CHECK_FORCE_QUIT()
                     
                     # add combinations
                     for item1 in ('Na', 'K', 'Li', 'NH4'):
-                        if item1 in config.compounds['adducts']:
+                        if item1 in config.compoundsSearch['adducts']:
                             for item2 in ('ACN', 'MeOH', '-H2O'):
-                                if item2 in config.compounds['adducts']:
+                                if item2 in config.compoundsSearch['adducts']:
                                     
                                     if item2 in ('ACN', 'MeOH'):
                                         adduct = '%s+%s' % (item1, item2)
@@ -866,7 +863,7 @@ class panelCompoundsSearch(wx.MiniFrame):
                                     
                                     formula = mspy.compound(formula)
                                     if formula.isvalid():
-                                        mz = formula.mz(z*polarity)[config.compounds['massType']]
+                                        mz = formula.mz(z*polarity)[config.compoundsSearch['massType']]
                                         self.currentCompounds.append([name, mz, z*polarity, adduct, formula.expression, None, []])
         
         # task canceled
