@@ -205,9 +205,16 @@ class panelDocuments(wx.Panel):
             menu.Append(ID_sequenceNew, "Add Sequence...")
             menu.AppendSeparator()
             menu.Append(ID_documentInfo, "Notes and Information...")
-            menu.Append(ID_documentColour, "Change Colour...")
             menu.Append(ID_documentNotationsDelete, "Delete All Notations")
             menu.AppendSeparator()
+            menu.Append(ID_documentColour, "Change Colour...")
+            style = wx.Menu()
+            style.Append(ID_documentStyleSolid, "Solid", "", wx.ITEM_RADIO)
+            style.Append(ID_documentStyleDot, "Dotted", "", wx.ITEM_RADIO)
+            style.Append(ID_documentStyleDash, "Dashed", "", wx.ITEM_RADIO)
+            style.Append(ID_documentStyleDotDash, "Dot and Dash", "", wx.ITEM_RADIO)
+            menu.AppendMenu(ID_documentStyle, "Line Style", style)
+            menu.AppendSeparator()
             menu.Append(ID_documentFlip, "Flip Spectrum")
             menu.Append(ID_documentOffset, "Offset Spectrum...")
             menu.Append(ID_documentClearOffset, "Clear Offset")
@@ -221,6 +228,17 @@ class panelDocuments(wx.Panel):
                 menu.Enable(ID_documentOffset, False)
             if itemData.offset == [0,0]:
                 menu.Enable(ID_documentClearOffset, False)
+            
+            if itemData.spectrum.hasprofile() == False:
+                menu.Enable(ID_documentStyle, False)
+            elif itemData.style == wx.DOT:
+                style.Check(ID_documentStyleDot, True)
+            elif itemData.style == wx.SHORT_DASH:
+                style.Check(ID_documentStyleDash, True)
+            elif itemData.style == wx.DOT_DASH:
+                style.Check(ID_documentStyleDotDash, True)
+            else:
+                style.Check(ID_documentStyleSolid, True)
         
         elif itemType == 'annotations':
             menu.Append(ID_documentAnnotationsCalibrateBy, "Calibrate by Annotations...")
@@ -285,6 +303,10 @@ class panelDocuments(wx.Panel):
         # bind events
         self.Bind(wx.EVT_MENU, self.parent.onDocumentInfo, id=ID_documentInfo)
         self.Bind(wx.EVT_MENU, self.parent.onDocumentColour, id=ID_documentColour)
+        self.Bind(wx.EVT_MENU, self.parent.onDocumentStyle, id=ID_documentStyleSolid)
+        self.Bind(wx.EVT_MENU, self.parent.onDocumentStyle, id=ID_documentStyleDot)
+        self.Bind(wx.EVT_MENU, self.parent.onDocumentStyle, id=ID_documentStyleDash)
+        self.Bind(wx.EVT_MENU, self.parent.onDocumentStyle, id=ID_documentStyleDotDash)
         self.Bind(wx.EVT_MENU, self.parent.onDocumentFlip, id=ID_documentFlip)
         self.Bind(wx.EVT_MENU, self.parent.onDocumentOffset, id=ID_documentOffset)
         self.Bind(wx.EVT_MENU, self.parent.onDocumentOffset, id=ID_documentClearOffset)
