@@ -257,8 +257,8 @@ class panelEnvelopeFit(wx.MiniFrame):
         self.updateCanvasProperties(refresh=False)
         self.spectrumCanvas.setProperties(showZero=False)
         self.spectrumCanvas.setProperties(showLegend=True)
-        self.spectrumCanvas.setProperties(showPosBar=False)
-        self.spectrumCanvas.setProperties(showIntBar=True)
+        self.spectrumCanvas.setProperties(showXPosBar=False)
+        self.spectrumCanvas.setProperties(showYPosBar=True)
         self.spectrumCanvas.setProperties(showGel=False)
         self.spectrumCanvas.setProperties(zoomAxis='x')
         self.spectrumCanvas.setProperties(checkLimits=True)
@@ -446,7 +446,7 @@ class panelEnvelopeFit(wx.MiniFrame):
         # check errors
         if error:
             wx.Bell()
-            dlg = mwx.dlgMessage(self, title="No data to fit.", message="There are no data in relevant mass range. Please check\nspecified formula and charge.")
+            dlg = mwx.dlgMessage(self, title="No data to fit.", message="There are no data in relevant mass range. Please check\nspecified formula, charge and default FWHM.")
             dlg.ShowModal()
             dlg.Destroy()
     # ----
@@ -568,7 +568,7 @@ class panelEnvelopeFit(wx.MiniFrame):
         self.spectrumCanvas.setProperties(yLabel=config.spectrum['yLabel'])
         self.spectrumCanvas.setProperties(showGrid=config.spectrum['showGrid'])
         self.spectrumCanvas.setProperties(showMinorTicks=config.spectrum['showMinorTicks'])
-        self.spectrumCanvas.setProperties(intBarHeight=config.spectrum['barHeight'])
+        self.spectrumCanvas.setProperties(posBarSize=config.spectrum['posBarSize'])
         self.spectrumCanvas.setProperties(xPosDigits=config.main['mzDigits'])
         self.spectrumCanvas.setProperties(yPosDigits=config.main['intDigits'])
         self.spectrumCanvas.setProperties(distanceDigits=config.main['mzDigits'])
@@ -660,7 +660,9 @@ class panelEnvelopeFit(wx.MiniFrame):
         try:
             
             # get scales
-            scales = [(x) for x in range(config.envelopeFit['scaleMin'], config.envelopeFit['scaleMax']+1)]
+            scaleMin = max(0, min(config.envelopeFit['scaleMin'], config.envelopeFit['scaleMax']))
+            scaleMax = max(0, max(config.envelopeFit['scaleMin'], config.envelopeFit['scaleMax']))
+            scales = [(x) for x in range(scaleMin, scaleMax+1)]
             
             # init module
             self.currentFit = mspy.envfit(
