@@ -359,10 +359,9 @@ class panelMassCalculator(wx.MiniFrame):
         self.patternCanvas.setProperties(showGrid=True)
         self.patternCanvas.setProperties(showMinorTicks=False)
         self.patternCanvas.setProperties(showLegend=True)
-        self.patternCanvas.setProperties(showPosBar=True)
-        self.patternCanvas.setProperties(showIntBar=True)
-        self.patternCanvas.setProperties(posBarHeight=6)
-        self.patternCanvas.setProperties(intBarHeight=6)
+        self.patternCanvas.setProperties(showXPosBar=True)
+        self.patternCanvas.setProperties(showYPosBar=True)
+        self.patternCanvas.setProperties(posBarSize=6)
         self.patternCanvas.setProperties(showGel=False)
         self.patternCanvas.setProperties(zoomAxis='x')
         self.patternCanvas.setProperties(checkLimits=True)
@@ -958,8 +957,10 @@ class panelMassCalculator(wx.MiniFrame):
                 
                 # add to list
                 self.currentIons.append((abs(charge), mz[0], mz[1], charge, iontype))
-                if config.massCalculator['ionseriesAgent'] == 'e':
-                    break
+                
+                # skip next radical ions
+                # if config.massCalculator['ionseriesAgent'] == 'e':
+                #     break
                 
                 # check limits
                 if mz[0] < 100 or len(self.currentIons) >= 100:
