@@ -40,8 +40,6 @@ class panelMassDefectPlot(wx.MiniFrame):
         self.parent = parent
         
         self.currentDocument = None
-        self.currentPeaks = None
-        self.currentNotations = None
         
         # make gui items
         self.makeGUI()
@@ -69,6 +67,7 @@ class panelMassDefectPlot(wx.MiniFrame):
         self.mainSizer.Fit(self)
         self.SetSizer(self.mainSizer)
         self.SetMinSize(self.GetSize())
+        self.Layout()
     # ----
     
     
@@ -79,46 +78,45 @@ class panelMassDefectPlot(wx.MiniFrame):
         panel = mwx.bgrPanel(self, -1, images.lib['bgrToolbar'], size=(-1, mwx.TOOLBAR_HEIGHT))
         
         # make tools
-        xAxis_label = wx.StaticText(panel, -1, "X axis:")
-        xAxis_label.SetFont(wx.SMALL_FONT)
-        
-        choices = ['m/z', 'Nominal Mass', 'Kendrick Mass', 'Kendrick Mass(F)']
-        self.xAxis_choice = wx.Choice(panel, -1, choices=choices, size=(175, mwx.SMALL_CHOICE_HEIGHT))
-        self.xAxis_choice.Select(0)
-        if config.massDefectPlot['xAxis'] in choices:
-            self.xAxis_choice.Select(choices.index(config.massDefectPlot['xAxis']))
-        
-        yAxis_label = wx.StaticText(panel, -1, "Y axis:")
+        yAxis_label = wx.StaticText(panel, -1, "MD type:")
         yAxis_label.SetFont(wx.SMALL_FONT)
-        
-        choices = ['Fractional Mass', 'Mass Defect', 'Relative Mass Defect', 'Kendrick Mass Defect', 'Kendrick Mass Defect (F)']
-        self.yAxis_choice = wx.Choice(panel, -1, choices=choices, size=(200, mwx.SMALL_CHOICE_HEIGHT))
-        self.yAxis_choice.Select(0)
+        choices = ['Fractional Mass', 'Mass Defect', 'Relative Mass Defect', 'Kendrick Mass Defect']
+        self.yAxis_choice = wx.Choice(panel, -1, choices=choices, size=(175, mwx.SMALL_CHOICE_HEIGHT))
+        self.yAxis_choice.Select(1)
+        choices = ['fraction', 'standard', 'relative', 'kendrick']
         if config.massDefectPlot['yAxis'] in choices:
             self.yAxis_choice.Select(choices.index(config.massDefectPlot['yAxis']))
-        self.yAxis_choice.Bind(wx.EVT_CHOICE, self.onYAxisChanged)
+        self.yAxis_choice.Bind(wx.EVT_CHOICE, self.onAxisChanged)
         
-        groupFormula_label = wx.StaticText(panel, -1, "Group formula:")
-        groupFormula_label.SetFont(wx.SMALL_FONT)
-        self.groupFormula_value = mwx.formulaCtrl(panel, -1, "", size=(80, -1))
+        nominalMass_label = wx.StaticText(panel, -1, "Nominal mass:")
+        nominalMass_label.SetFont(wx.SMALL_FONT)
+        choices = ['Ceil', 'Round', 'Floor']
+        self.nominalMass_choice = wx.Choice(panel, -1, choices=choices, size=(80, mwx.SMALL_CHOICE_HEIGHT))
+        self.nominalMass_choice.Select(1)
+        if config.massDefectPlot['nominalMass'].title() in choices:
+            self.nominalMass_choice.Select(choices.index(config.massDefectPlot['nominalMass'].title()))
         
-        self.onYAxisChanged()
+        kendrickFormula_label = wx.StaticText(panel, -1, "Kendrick formula:")
+        kendrickFormula_label.SetFont(wx.SMALL_FONT)
+        self.kendrickFormula_value = mwx.formulaCtrl(panel, -1, config.massDefectPlot['kendrickFormula'], size=(80, -1))
         
         # make buttons
         self.plot_butt = wx.Button(panel, -1, "Plot", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
         self.plot_butt.Bind(wx.EVT_BUTTON, self.onPlot)
         
+        self.onAxisChanged()
+        
         # pack elements
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.AddSpacer(mwx.CONTROLBAR_LSPACE)
-        sizer.Add(xAxis_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
-        sizer.Add(self.xAxis_choice, 0, wx.ALIGN_CENTER_VERTICAL)
-        sizer.AddSpacer(20)
         sizer.Add(yAxis_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(self.yAxis_choice, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddSpacer(20)
-        sizer.Add(groupFormula_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
-        sizer.Add(self.groupFormula_value, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.Add(nominalMass_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
+        sizer.Add(self.nominalMass_choice, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.AddSpacer(20)
+        sizer.Add(kendrickFormula_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
+        sizer.Add(self.kendrickFormula_value, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddStretchSpacer()
         sizer.AddSpacer(20)
         sizer.Add(self.plot_butt, 0, wx.ALIGN_CENTER_VERTICAL)
@@ -140,49 +138,45 @@ class panelMassDefectPlot(wx.MiniFrame):
         panel = mwx.bgrPanel(self, -1, images.lib['bgrControlbar'], size=(-1, mwx.CONTROLBAR_HEIGHT))
         
         # make elements
-        nominalMass_label = wx.StaticText(panel, -1, "Nominal mass:")
-        nominalMass_label.SetFont(wx.SMALL_FONT)
-        choices = ['Round', 'Floor', 'Ceil']
-        self.nominalMass_choice = wx.Choice(panel, -1, choices=choices, size=(80, mwx.SMALL_CHOICE_HEIGHT))
-        self.nominalMass_choice.Select(0)
-        if config.massDefectPlot['nominalMass'].title() in choices:
-            self.nominalMass_choice.Select(choices.index(config.massDefectPlot['nominalMass'].title()))
-        
-        relIntCutoff_label = wx.StaticText(panel, -1, "Rel. int. threshold:")
+        relIntCutoff_label = wx.StaticText(panel, -1, "Int. threshold:")
         relIntCutoff_label.SetFont(wx.SMALL_FONT)
         relIntCutoffUnits_label = wx.StaticText(panel, -1, "%")
         relIntCutoffUnits_label.SetFont(wx.SMALL_FONT)
         self.relIntCutoff_value = wx.TextCtrl(panel, -1, str(config.massDefectPlot['relIntCutoff']*100), size=(50, mwx.SMALL_TEXTCTRL_HEIGHT), validator=mwx.validator('floatPos'))
         self.relIntCutoff_value.SetFont(wx.SMALL_FONT)
         
-        self.ignoreCharge_check = wx.CheckBox(panel, -1, "Ignore charge")
-        self.ignoreCharge_check.SetFont(wx.SMALL_FONT)
-        self.ignoreCharge_check.SetValue(config.massDefectPlot['ignoreCharge'])
-        
         self.removeIsotopes_check = wx.CheckBox(panel, -1, "Remove isotopes")
         self.removeIsotopes_check.SetFont(wx.SMALL_FONT)
         self.removeIsotopes_check.SetValue(config.massDefectPlot['removeIsotopes'])
         
+        self.ignoreCharge_check = wx.CheckBox(panel, -1, "Ignore charge")
+        self.ignoreCharge_check.SetFont(wx.SMALL_FONT)
+        self.ignoreCharge_check.SetValue(config.massDefectPlot['ignoreCharge'])
+        
         self.showNotations_check = wx.CheckBox(panel, -1, "Highlight annotated")
         self.showNotations_check.SetFont(wx.SMALL_FONT)
         self.showNotations_check.SetValue(config.massDefectPlot['showNotations'])
         self.showNotations_check.Bind(wx.EVT_CHECKBOX, self.onShowNotations)
         
+        self.showAllDocuments_check = wx.CheckBox(panel, -1, "Show all documents")
+        self.showAllDocuments_check.SetFont(wx.SMALL_FONT)
+        self.showAllDocuments_check.SetValue(False)
+        self.showAllDocuments_check.Bind(wx.EVT_CHECKBOX, self.onShowAllDocuments)
+        
         # pack elements
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.AddSpacer(mwx.CONTROLBAR_LSPACE)
-        sizer.Add(nominalMass_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
-        sizer.Add(self.nominalMass_choice, 0, wx.ALIGN_CENTER_VERTICAL)
-        sizer.AddSpacer(20)
         sizer.Add(relIntCutoff_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(self.relIntCutoff_value, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(relIntCutoffUnits_label, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddSpacer(20)
-        sizer.Add(self.ignoreCharge_check, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
-        sizer.AddSpacer(20)
         sizer.Add(self.removeIsotopes_check, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddSpacer(20)
+        sizer.Add(self.ignoreCharge_check, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.AddSpacer(20)
         sizer.Add(self.showNotations_check, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.AddSpacer(20)
+        sizer.Add(self.showAllDocuments_check, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddSpacer(mwx.CONTROLBAR_RSPACE)
         
         mainSizer = wx.BoxSizer(wx.VERTICAL)
@@ -199,7 +193,7 @@ class panelMassDefectPlot(wx.MiniFrame):
         
         # init canvas
         self.plotCanvas = mspy.plot.canvas(self, size=(650, 300), style=mwx.PLOTCANVAS_STYLE_PANEL)
-        self.plotCanvas.draw(mspy.plot.container([]))
+        self.plotCanvasContainer = mspy.plot.container([])
         
         # set default params
         self.plotCanvas.setProperties(xLabel='m/z')
@@ -208,10 +202,9 @@ class panelMassDefectPlot(wx.MiniFrame):
         self.plotCanvas.setProperties(showZero=True)
         self.plotCanvas.setProperties(showGrid=True)
         self.plotCanvas.setProperties(showMinorTicks=False)
-        self.plotCanvas.setProperties(showPosBar=True)
-        self.plotCanvas.setProperties(posBarHeight=6)
-        self.plotCanvas.setProperties(showIntBar=True)
-        self.plotCanvas.setProperties(intBarHeight=6)
+        self.plotCanvas.setProperties(showXPosBar=True)
+        self.plotCanvas.setProperties(showYPosBar=True)
+        self.plotCanvas.setProperties(posBarSize=6)
         self.plotCanvas.setProperties(showGel=False)
         self.plotCanvas.setProperties(zoomAxis='xy')
         self.plotCanvas.setProperties(checkLimits=True)
@@ -219,16 +212,16 @@ class panelMassDefectPlot(wx.MiniFrame):
         self.plotCanvas.setProperties(xPosDigits=config.main['mzDigits'])
         self.plotCanvas.setProperties(yPosDigits=config.main['mzDigits'])
         self.plotCanvas.setProperties(reverseScrolling=config.main['reverseScrolling'])
-        self.plotCanvas.setProperties(reverseDrawing=False)
+        self.plotCanvas.setProperties(reverseDrawing=True)
         self.plotCanvas.setMFunction('cross')
         self.plotCanvas.setLMBFunction('xDistance')
         
         axisFont = wx.Font(config.spectrum['axisFontSize'], wx.SWISS, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, 0)
         self.plotCanvas.setProperties(axisFont=axisFont)
         
-        self.plotCanvas.canvas.Bind(wx.EVT_LEFT_UP, self.onPlotCanvasLMU)
+        self.plotCanvas.draw(self.plotCanvasContainer)
         
-        self.plotCanvas.draw(mspy.plot.container([]))
+        self.plotCanvas.Bind(wx.EVT_LEFT_UP, self.onPlotCanvasLMU)
     # ----
     
     
@@ -240,29 +233,49 @@ class panelMassDefectPlot(wx.MiniFrame):
     # ----
     
     
-    def onPlot(self, evt):
+    def onPlot(self, evt=None):
         """Calculate and show mass defect plot."""
         
         # clear previous data
-        self.currentPeaks = None
-        self.currentNotations = None
-        
-        # check document
-        if not self.currentDocument or not self.currentDocument.spectrum.haspeaks():
-            wx.Bell()
-            return
+        self.plotCanvasContainer.empty()
         
         # get params
         if not self.getParams():
-            self.updatePlotCanvas()
+            self.plotCanvas.refresh()
             wx.Bell()
             return
         
-        # calculate data points
-        self.calcDataPoints()
+        # show annotations for current document on top
+        if self.currentDocument != None and config.massDefectPlot['showNotations']:
+            
+            buff = []
+            for item in self.currentDocument.annotations:
+                buff.append((item.mz, item.charge))
+            for sequence in self.currentDocument.sequences:
+                for item in sequence.matches:
+                    buff.append((item.mz, item.charge))
+            
+            points = self.makeDataPoints(mspy.peaklist(buff), self.currentDocument.spectrum.polarity)
+            obj = mspy.plot.points(points, pointColour=(255,0,0), showPoints=True, showLines=False)
+            self.plotCanvasContainer.append(obj)
+        
+        # show all documents
+        if config.massDefectPlot['showAllDocuments']:
+            for docData in self.parent.documents:
+                if docData.visible:
+                    points = self.makeDataPoints(docData.spectrum.peaklist, docData.spectrum.polarity)
+                    obj = mspy.plot.points(points, pointColour=docData.colour, showPoints=True, showLines=False)
+                    self.plotCanvasContainer.append(obj)
+        
+        # show current document only
+        elif self.currentDocument != None:
+            points = self.makeDataPoints(self.currentDocument.spectrum.peaklist, self.currentDocument.spectrum.polarity)
+            obj = mspy.plot.points(points, pointColour=(0,255,0), showPoints=True, showLines=False)
+            self.plotCanvasContainer.append(obj)
         
         # update plot
-        self.updatePlotCanvas()
+        self.updatePlotCanvasLabels()
+        self.plotCanvas.draw(self.plotCanvasContainer)
     # ----
     
     
@@ -289,24 +302,21 @@ class panelMassDefectPlot(wx.MiniFrame):
     # ----
     
     
-    def onYAxisChanged(self, evt=None):
-        """Update unit formula value."""
+    def onAxisChanged(self, evt=None):
+        """Enable / disable Kendrick formula field."""
         
         # get current selection
-        selected = self.yAxis_choice.GetStringSelection()
+        yAxis = self.yAxis_choice.GetStringSelection()
         
-        # set Kendrick formula
-        if selected == 'Kendrick Mass Defect':
-            self.groupFormula_value.SetValue('CH2')
+        # enable/disable Kendrick formula
+        if yAxis == 'Kendrick Mass Defect':
+            self.kendrickFormula_value.Enable()
         else:
-            self.groupFormula_value.SetValue('')
+            self.kendrickFormula_value.Disable()
         
-        # enable custom formula
-        if selected == 'Kendrick Mass Defect (F)':
-            self.groupFormula_value.Enable()
-            self.groupFormula_value.SetValue(config.massDefectPlot['groupFormula'])
-        else:
-            self.groupFormula_value.Disable()
+        # ensure Kendrick formula is set
+        if not self.kendrickFormula_value.GetValue():
+            self.kendrickFormula_value.SetValue('CH2')
     # ----
     
     
@@ -317,7 +327,18 @@ class panelMassDefectPlot(wx.MiniFrame):
         config.massDefectPlot['showNotations'] = self.showNotations_check.GetValue()
         
         # update plot
-        self.updatePlotCanvas()
+        self.onPlot()
+    # ----
+    
+    
+    def onShowAllDocuments(self, evt):
+        """Show current document or all visible."""
+        
+        # get value
+        config.massDefectPlot['showAllDocuments'] = self.showAllDocuments_check.GetValue()
+        
+        # update plot
+        self.onPlot()
     # ----
     
     
@@ -327,12 +348,8 @@ class panelMassDefectPlot(wx.MiniFrame):
         # set new document
         self.currentDocument = document
         
-        # clear previous data
-        self.currentPeaks = None
-        self.currentNotations = None
-        
         # update plot
-        self.updatePlotCanvas()
+        self.onPlot()
     # ----
     
     
@@ -342,17 +359,21 @@ class panelMassDefectPlot(wx.MiniFrame):
         # try to get values
         try:
             
-            config.massDefectPlot['xAxis'] = self.xAxis_choice.GetStringSelection()
-            config.massDefectPlot['yAxis'] = self.yAxis_choice.GetStringSelection()
+            choices = ['fraction', 'standard', 'relative', 'kendrick']
+            config.massDefectPlot['yAxis'] = choices[self.yAxis_choice.GetSelection()]
+            
             config.massDefectPlot['nominalMass'] = self.nominalMass_choice.GetStringSelection().lower()
             config.massDefectPlot['relIntCutoff'] = float(self.relIntCutoff_value.GetValue())/100.
-            config.massDefectPlot['ignoreCharge'] = self.ignoreCharge_check.GetValue()
             config.massDefectPlot['removeIsotopes'] = self.removeIsotopes_check.GetValue()
+            config.massDefectPlot['ignoreCharge'] = self.ignoreCharge_check.GetValue()
             config.massDefectPlot['showNotations'] = self.showNotations_check.GetValue()
+            config.massDefectPlot['showAllDocuments'] = self.showAllDocuments_check.GetValue()
             
-            formula = self.groupFormula_value.GetValue()
+            formula = self.kendrickFormula_value.GetValue()
             cmpd = mspy.compound(formula)
-            config.massDefectPlot['groupFormula'] = str(formula)
+            config.massDefectPlot['kendrickFormula'] = str(formula)
+            if config.massDefectPlot['yAxis'] == 'kendrick' and cmpd.mass(0) == 0:
+                raise ValueError
             
             return True
         
@@ -362,148 +383,116 @@ class panelMassDefectPlot(wx.MiniFrame):
     # ----
     
     
-    def updatePlotCanvas(self):
-        """Update plot canvas."""
+    def updateDocuments(self):
+        """Reload all visible documents."""
         
-        # make container
-        container = mspy.plot.container([])
+        # skip if current document only is shown
+        if not config.massDefectPlot['showAllDocuments']:
+            return
         
-        # set axis labels
-        xLabel=config.massDefectPlot['xAxis']
-        yLabel = config.massDefectPlot['yAxis']
+        # reload visible documents
+        self.onPlot()
+    # ----
+    
+    
+    def updatePlotCanvasLabels(self):
+        """Update plot canvas axes labels."""
         
-        if config.massDefectPlot['yAxis'] == 'Custom Unit Mass Defect':
-            yLabel = '%s (%s)' % (config.massDefectPlot['yAxis'], config.massDefectPlot['groupFormula'])
+        xLabel = 'm/z'
+        yLabel = 'mass defect'
+        
+        # set x axis
+        if config.massDefectPlot['xAxis'] == 'mz':
+            xLabel = 'm/z'
+        elif config.massDefectPlot['xAxis'] == 'nominal':
+            xLabel = 'nominal mass'
+        elif config.massDefectPlot['xAxis'] == 'kendrick':
+            xLabel = 'kendrick mass'
+        
+        # set y axis
+        if config.massDefectPlot['yAxis'] == 'fraction':
+            yLabel = 'fractional mass'
+        elif config.massDefectPlot['yAxis'] == 'standard':
+            yLabel = 'mass defect'
+        elif config.massDefectPlot['yAxis'] == 'relative':
+            yLabel = 'relative mass defect'
+        elif config.massDefectPlot['yAxis'] == 'kendrick':
+            yLabel = 'kendrick mass defect'
         
         self.plotCanvas.setProperties(xLabel=xLabel)
         self.plotCanvas.setProperties(yLabel=yLabel)
-        
-        # check data
-        if self.currentPeaks == None and self.currentNotations == None:
-            self.plotCanvas.draw(container)
-            return
-        
-        # make points objects
-        if self.currentPeaks != None:
-            points = mspy.plot.points(self.currentPeaks, pointColour=(0,255,0), showPoints=True, showLines=False, legend='peak list')
-            container.append(points)
-        
-        if self.currentNotations != None and config.massDefectPlot['showNotations']:
-            points = mspy.plot.points(self.currentNotations, pointColour=(255,0,0), showPoints=True, showLines=False, legend='annotated')
-            container.append(points)
-        
-        # draw container
-        self.plotCanvas.draw(container)
     # ----
     
     
-    def calcDataPoints(self):
-        """Calculate mass defect plot data."""
-        
-        # clear previous data
-        self.currentPeaks = []
-        self.currentNotations = []
+    def makeDataPoints(self, peaklist, polarity=1):
+        """Make plot points for spectrum peaklist."""
         
         # get spectrum polarity
-        polarity = self.currentDocument.spectrum.polarity
         if not polarity:
             polarity = 1
         
-        # calculate mass defect for peaks
+        # get peaks
         buff = []
-        for peak in self.currentDocument.spectrum.peaklist:
+        for peak in peaklist:
+            
+            # remove isotopes
             if config.massDefectPlot['removeIsotopes'] and not peak.isotope in (0, None):
                 continue
-            if peak.ri >= config.massDefectPlot['relIntCutoff']:
-                buff.append([peak.mz, peak.charge])
+            
+            # remove low abundant peaks
+            if peak.ri < config.massDefectPlot['relIntCutoff']:
+                continue
+            
+            # append point to buffer
+            buff.append([peak.mz, peak.charge])
         
-        self.currentPeaks = self.calcMassDefect(buff, polarity)
+        # calculate mass and mass defect for each point
+        points = self.calcDataPoints(buff, polarity)
         
-        # calculate mass defect for notations
-        items = []
-        for item in self.currentDocument.annotations:
-            items.append(item)
-        for sequence in self.currentDocument.sequences:
-            for item in sequence.matches:
-                items.append(item)
-        
-        basepeak = self.currentDocument.spectrum.peaklist.basepeak
-        if basepeak:
-            basepeak = basepeak.intensity
-        
-        buff = []
-        for item in items:
-            if not basepeak or (item.ai-item.base)/basepeak >= config.massDefectPlot['relIntCutoff']:
-                buff.append([item.mz, item.charge])
-        
-        self.currentNotations = self.calcMassDefect(buff, polarity)
+        return points
     # ----
     
     
-    def calcMassDefect(self, peaks, polarity=1):
-        """Calculate mass defect plot data."""
+    def calcDataPoints(self, peaks, polarity=1):
+        """Calculate requested mass and mass defect."""
         
         buff = []
         
-        # init rounding fn
-        if config.massDefectPlot['nominalMass'] == 'floor':
-            nominalMass = math.floor
-        elif config.massDefectPlot['nominalMass'] == 'ceil':
-            nominalMass = math.ceil
-        else:
-            nominalMass = round
-        
-        # init Kendrick factor
-        kendrickF = 1.
-        if config.massDefectPlot['groupFormula']:
-            group = mspy.compound(config.massDefectPlot['groupFormula'])
-            kendrickF = group.nominalmass(0)/group.mass(0)
+        # init Kendrick formula
+        kendrickFormula = mspy.compound(config.massDefectPlot['kendrickFormula'])
         
         # calculate data points
         for peak in peaks:
             
-            mz = peak[0]
-            mzDecon = peak[0]
+            mass = peak[0]
             if not config.massDefectPlot['ignoreCharge'] and peak[1]:
-                mzDecon = mspy.mz(peak[0], 1*polarity, peak[1], agentFormula='H', agentCharge=1)
+                mass = mspy.mz(peak[0], 1*polarity, peak[1], agentFormula='H', agentCharge=1)
             
-            # init point
-            point = [mz, 0.0]
+            # calc mass defect
+            md = mspy.md(
+                mass = mass,
+                mdType = config.massDefectPlot['yAxis'],
+                kendrickFormula = kendrickFormula,
+                rounding = config.massDefectPlot['nominalMass']
+            )
             
-            # make X axis
-            if config.massDefectPlot['xAxis'] == 'm/z':
-                pass
+            # re-calculate selected mass
+            if config.massDefectPlot['xAxis'] == 'mz':
+                mass = peak[0]
             
-            elif config.massDefectPlot['xAxis'] == 'Nominal Mass':
-                point[0] = nominalMass(mz)
+            elif config.massDefectPlot['xAxis'] == 'nominal':
+                mass = mspy.nominalmass(peak[0], config.massDefectPlot['nominalMass'])
             
-            elif config.massDefectPlot['xAxis'] == 'Kendrick Mass':
-                point[0] = mz * kendrickF
+            elif config.massDefectPlot['xAxis'] == 'kendrick':
+                mass = mspy.nominalmass(peak[0] * kendrickFormula.nominalmass()/kendrickFormula.mass(0))
             
-            elif config.massDefectPlot['xAxis'] == 'Kendrick Mass (F)':
-                point[0] = mz * kendrickF
-            
-            # make Y axis
-            if config.massDefectPlot['yAxis'] == 'Fractional Mass':
-                point[1] = math.modf(mz)[0]
-            
-            elif config.massDefectPlot['yAxis'] == 'Mass Defect':
-                point[1] = nominalMass(mzDecon) - mzDecon
-            
-            elif config.massDefectPlot['yAxis'] == 'Relative Mass Defect':
-                point[1] = ((nominalMass(mzDecon) - mzDecon) / mzDecon) * 1e6
-            
-            elif config.massDefectPlot['yAxis'] == 'Kendrick Mass Defect':
-                point[1] = nominalMass(mzDecon * kendrickF) - (mzDecon * kendrickF)
-            
-            elif config.massDefectPlot['yAxis'] == 'Kendrick Mass Defect (F)':
-                point[1] = nominalMass(mzDecon * kendrickF) - (mzDecon * kendrickF)
+            else:
+                mass = peak[0]
             
             # append point
-            buff.append(point)
+            buff.append((mass, md))
         
         return buff
     # ----
     
     
-
