@@ -929,6 +929,11 @@ class panelMassToFormula(wx.MiniFrame):
         # get script
         script = config.massToFormula[server.replace(' ', '')+'Script']
         
+        # get method
+        method = 'post'
+        if server in ['ChemSpider', 'HMDB']:
+            method = 'get'
+        
         # get formula
         formula = self._escape(formula)
         
@@ -964,7 +969,7 @@ class panelMassToFormula(wx.MiniFrame):
         # page start
         buff += '<body onload="runsearch()">\n'
         buff += '<body>\n'
-        buff += '  <form action="%s" id="mainSearch" enctype="multipart/form-data" method="post">\n' % (script)
+        buff += '  <form action="%s" id="mainSearch" enctype="multipart/form-data" method="%s">\n' % (script, method)
         buff += '    <div style="display:none;">\n\n'
             
         # search query
@@ -980,15 +985,13 @@ class panelMassToFormula(wx.MiniFrame):
             buff += '      <input type="text" name="q_data" value="%s" />\n' % (formula)
         
         elif server == 'ChemSpider':
-            buff += '      <input type="hidden" name="__EVENTTARGET" value="ctl00$ctl00$qs_query" />\n'
-            buff += '      <input type="hidden" name="__EVENTARGUMENT" value="" />\n'
-            buff += '      <input type="text" name="ctl00$ctl00$qs_query" value="%s"  />\n' % (formula)
+            buff += '      <input type="text" name="q" value="%s"  />\n' % (formula)
         
         elif server == 'METLIN':
             buff += '      <input type="text" name="formula" value="%s"  />\n' % (formula)
         
         elif server == 'HMDB':
-            buff += '      <input type="text" name="query" value="chemical_formula:%s"  />\n' % (formula)
+            buff += '      <input type="text" name="query" value="%s"  />\n' % (formula)
         
         elif server == 'Lipid MAPS':
             buff += '      <input type="hidden" name="Mode" value="ProcessTextOntologySearch" />\n'
