@@ -243,8 +243,8 @@ class panelMatch(wx.MiniFrame):
         self.errorCanvas.setProperties(showGrid=True)
         self.errorCanvas.setProperties(showMinorTicks=False)
         self.errorCanvas.setProperties(showLegend=False)
-        self.errorCanvas.setProperties(showPosBar=True)
-        self.errorCanvas.setProperties(posBarHeight=6)
+        self.errorCanvas.setProperties(showXPosBar=True)
+        self.errorCanvas.setProperties(posBarSize=6)
         self.errorCanvas.setProperties(showGel=False)
         self.errorCanvas.setProperties(zoomAxis='x')
         self.errorCanvas.setProperties(checkLimits=True)
