@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -96,22 +96,19 @@ class panelPeriodicTable(wx.MiniFrame):
         highlight_label = wx.StaticText(panel, -1, "Highlight:")
         highlight_label.SetFont(wx.SMALL_FONT)
         choices = ['None', '---', 'Metals', 'Alkali Metals', 'Alkaline Earth Metals', 'Inner Transition Metals', 'Lanthanides', 'Actinides', 'Transition Metals', 'Post-Transition Metals', '---', 'Nonmetals', 'Halogens', 'Noble Gasses', 'Other Nonmetals', '---', 'Metalloids']
-        self.highlight_combo = wx.ComboBox(panel, -1, choices=choices, size=(-1, mwx.SMALL_COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.highlight_combo.Select(0)
-        self.highlight_combo.Bind(wx.EVT_COMBOBOX, self.onHighlightGroup)
+        self.highlight_choice = wx.Choice(panel, -1, choices=choices, size=(-1, mwx.SMALL_CHOICE_HEIGHT))
+        self.highlight_choice.Select(0)
+        self.highlight_choice.Bind(wx.EVT_CHOICE, self.onHighlightGroup)
         
         # make buttons
         self.isotopes_butt = wx.Button(panel, -1, "Isotopes", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.isotopes_butt.SetFont(wx.SMALL_FONT)
         self.isotopes_butt.Bind(wx.EVT_BUTTON, self.onIsotopes)
         self.isotopes_butt.Enable(False)
         
         self.wiki_butt = wx.Button(panel, -1, "Wikipedia", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.wiki_butt.SetFont(wx.SMALL_FONT)
         self.wiki_butt.Bind(wx.EVT_BUTTON, self.onWiki)
         
         self.photos_butt = wx.Button(panel, -1, "Photos", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.photos_butt.SetFont(wx.SMALL_FONT)
         self.photos_butt.Bind(wx.EVT_BUTTON, self.onPhotos)
         self.photos_butt.Enable(False)
         
@@ -119,7 +116,7 @@ class panelPeriodicTable(wx.MiniFrame):
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.AddSpacer(mwx.CONTROLBAR_LSPACE)
         sizer.Add(highlight_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
-        sizer.Add(self.highlight_combo, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.Add(self.highlight_choice, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddStretchSpacer()
         sizer.AddSpacer(20)
         sizer.Add(self.isotopes_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 10)
@@ -205,11 +202,11 @@ class panelPeriodicTable(wx.MiniFrame):
         self.onElementSelected(None)
         
         # get group
-        group = self.highlight_combo.GetValue()
+        group = self.highlight_choice.GetStringSelection()
         if group in self.groups:
             self.currentGroup = group
         else:
-            self.highlight_combo.SetValue('None')
+            self.highlight_choice.SetStringSelection('None')
         
         # select group elements
         for element in self.elementsButtons:
