@@ -589,6 +589,7 @@ class panelProcessing(wx.MiniFrame):
         panel = wx.Panel(self, -1)
         
         # make elements
+        self.batchSwap_check = wx.CheckBox(panel, -1, "Swap data")
         self.batchMath_check = wx.CheckBox(panel, -1, "Math")
         self.batchCrop_check = wx.CheckBox(panel, -1, "Crop")
         self.batchBaseline_check = wx.CheckBox(panel, -1, "Baseline correction")
@@ -603,13 +604,14 @@ class panelProcessing(wx.MiniFrame):
         
         # pack elements
         grid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
-        grid.Add(self.batchMath_check, (0,0))
-        grid.Add(self.batchCrop_check, (1,0))
-        grid.Add(self.batchBaseline_check, (2,0))
-        grid.Add(self.batchSmoothing_check, (3,0))
-        grid.Add(self.batchPeakpicking_check, (4,0))
-        grid.Add(self.batchDeisotoping_check, (5,0))
-        grid.Add(self.batchDeconvolution_check, (6,0))
+        grid.Add(self.batchSwap_check, (0,0))
+        grid.Add(self.batchMath_check, (1,0))
+        grid.Add(self.batchCrop_check, (2,0))
+        grid.Add(self.batchBaseline_check, (3,0))
+        grid.Add(self.batchSmoothing_check, (4,0))
+        grid.Add(self.batchPeakpicking_check, (5,0))
+        grid.Add(self.batchDeisotoping_check, (6,0))
+        grid.Add(self.batchDeconvolution_check, (7,0))
         
         mainSizer = wx.BoxSizer(wx.HORIZONTAL)
         mainSizer.Add(self.batchDocumentsList, 1, wx.EXPAND|wx.ALL, mwx.PANEL_SPACE_MAIN)
@@ -917,6 +919,7 @@ class panelProcessing(wx.MiniFrame):
         self.deconvolutionForceGroupWindow_check.SetValue(bool(presets['deconvolution']['forceGroupWindow']))
         
         # batch processing
+        self.batchSwap_check.SetValue(bool(presets['batch']['swap']))
         self.batchMath_check.SetValue(bool(presets['batch']['math']))
         self.batchCrop_check.SetValue(bool(presets['batch']['crop']))
         self.batchBaseline_check.SetValue(bool(presets['batch']['baseline']))
@@ -1348,6 +1351,7 @@ class panelProcessing(wx.MiniFrame):
             config.processing['deconvolution']['forceGroupWindow'] = bool(self.deconvolutionForceGroupWindow_check.GetValue())
             
             # batch processing
+            config.processing['batch']['swap'] = bool(self.batchSwap_check.GetValue())
             config.processing['batch']['math'] = bool(self.batchMath_check.GetValue())
             config.processing['batch']['crop'] = bool(self.batchCrop_check.GetValue())
             config.processing['batch']['baseline'] = bool(self.batchBaseline_check.GetValue())
@@ -1546,6 +1550,36 @@ class panelProcessing(wx.MiniFrame):
     # ----
     
     
+    def runApplySwap(self, batch=False):
+        """Crop data."""
+        
+        # check current spectrum
+        if not self.currentDocument:
+            wx.Bell()
+            return
+        
+        # run task
+        try:
+            
+            # backup document
+            if not batch:
+                self.currentDocument.backup(('spectrum', 'notations'))
+            
+            # swap spectrum data
+            self.currentDocument.spectrum.swap()
+            
+            # remove notations
+            del self.currentDocument.annotations[:]
+            for sequence in self.currentDocument.sequences:
+                del sequence.matches[:]
+            
+        # task canceled
+        except mspy.ForceQuit:
+            if batch: mspy.stop()
+            return
+    # ----
+    
+    
     def runApplyMath(self, batch=False):
         """Math operations."""
         
@@ -1939,6 +1973,10 @@ class panelProcessing(wx.MiniFrame):
                 # backup document
                 self.currentDocument.backup(('spectrum', 'notations'))
                 
+                # apply swap
+                if self.batchSwap_check.GetValue():
+                    self.runApplySwap(batch=True)
+                
                 # apply math
                 if self.batchMath_check.GetValue():
                     self.runApplyMath(batch=True)
