@@ -95,10 +95,9 @@ class panelSpectrum(wx.Panel):
         self.spectrumCanvas.setProperties(showGrid=config.spectrum['showGrid'])
         self.spectrumCanvas.setProperties(showMinorTicks=config.spectrum['showMinorTicks'])
         self.spectrumCanvas.setProperties(showLegend=config.spectrum['showLegend'])
-        self.spectrumCanvas.setProperties(showPosBar=config.spectrum['showPosBars'])
-        self.spectrumCanvas.setProperties(showIntBar=config.spectrum['showPosBars'])
-        self.spectrumCanvas.setProperties(posBarHeight=config.spectrum['barHeight'])
-        self.spectrumCanvas.setProperties(intBarHeight=config.spectrum['barHeight'])
+        self.spectrumCanvas.setProperties(showXPosBar=config.spectrum['showPosBars'])
+        self.spectrumCanvas.setProperties(showYPosBar=config.spectrum['showPosBars'])
+        self.spectrumCanvas.setProperties(posBarSize=config.spectrum['posBarSize'])
         self.spectrumCanvas.setProperties(showGel=config.spectrum['showGel'])
         self.spectrumCanvas.setProperties(gelHeight=config.spectrum['gelHeight'])
         self.spectrumCanvas.setProperties(showCurXPos=True)
@@ -119,13 +118,13 @@ class panelSpectrum(wx.Panel):
         self.spectrumCanvas.setProperties(axisFont=axisFont)
         
         # set events
-        self.spectrumCanvas.canvas.Bind(wx.EVT_MOTION, self.onCanvasMMotion)
-        self.spectrumCanvas.canvas.Bind(wx.EVT_MOUSEWHEEL, self.onCanvasMScroll)
-        self.spectrumCanvas.canvas.Bind(wx.EVT_LEFT_UP, self.onCanvasLMU)
+        self.spectrumCanvas.Bind(wx.EVT_MOTION, self.onCanvasMMotion)
+        self.spectrumCanvas.Bind(wx.EVT_MOUSEWHEEL, self.onCanvasMScroll)
+        self.spectrumCanvas.Bind(wx.EVT_LEFT_UP, self.onCanvasLMU)
         
         # set DnD
         dropTarget = fileDropTarget(self.parent.onDocumentDropped)
-        self.spectrumCanvas.canvas.SetDropTarget(dropTarget)
+        self.spectrumCanvas.SetDropTarget(dropTarget)
     # ----
     
     
@@ -538,10 +537,9 @@ class panelSpectrum(wx.Panel):
         self.spectrumCanvas.setProperties(checkLimits=config.spectrum['checkLimits'])
         self.spectrumCanvas.setProperties(autoScaleY=config.spectrum['autoscale'])
         self.spectrumCanvas.setProperties(showGel=config.spectrum['showGel'])
-        self.spectrumCanvas.setProperties(showPosBar=config.spectrum['showPosBars'])
-        self.spectrumCanvas.setProperties(showIntBar=config.spectrum['showPosBars'])
-        self.spectrumCanvas.setProperties(posBarHeight=config.spectrum['barHeight'])
-        self.spectrumCanvas.setProperties(intBarHeight=config.spectrum['barHeight'])
+        self.spectrumCanvas.setProperties(showXPosBar=config.spectrum['showPosBars'])
+        self.spectrumCanvas.setProperties(showYPosBar=config.spectrum['showPosBars'])
+        self.spectrumCanvas.setProperties(posBarSize=config.spectrum['posBarSize'])
         self.spectrumCanvas.setProperties(showLegend=config.spectrum['showLegend'])
         self.spectrumCanvas.setProperties(showGrid=config.spectrum['showGrid'])
         self.spectrumCanvas.setProperties(showMinorTicks=config.spectrum['showMinorTicks'])
@@ -1194,10 +1192,10 @@ class dlgCanvasProperties(wx.Dialog):
         self.intDigits_slider.SetTickFreq(1,1)
         self.intDigits_slider.Bind(wx.EVT_SCROLL, self.onChange)
         
-        barHeight_label = wx.StaticText(self, -1, "Bars height:")
-        self.barHeight_slider = wx.Slider(self, -1, config.spectrum['barHeight'], 5, 20, size=(150, -1), style=mwx.SLIDER_STYLE)
-        self.barHeight_slider.SetTickFreq(5,1)
-        self.barHeight_slider.Bind(wx.EVT_SCROLL, self.onChange)
+        posBarSize_label = wx.StaticText(self, -1, "Bars height:")
+        self.posBarSize_slider = wx.Slider(self, -1, config.spectrum['posBarSize'], 5, 20, size=(150, -1), style=mwx.SLIDER_STYLE)
+        self.posBarSize_slider.SetTickFreq(5,1)
+        self.posBarSize_slider.Bind(wx.EVT_SCROLL, self.onChange)
         
         gelHeight_label = wx.StaticText(self, -1, "Gel height:")
         self.gelHeight_slider = wx.Slider(self, -1, config.spectrum['gelHeight'], 10, 50, size=(150, -1), style=mwx.SLIDER_STYLE)
@@ -1225,8 +1223,8 @@ class dlgCanvasProperties(wx.Dialog):
         grid.Add(self.mzDigits_slider, (0,1))
         grid.Add(intDigits_label, (1,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         grid.Add(self.intDigits_slider, (1,1))
-        grid.Add(barHeight_label, (2,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        grid.Add(self.barHeight_slider, (2,1))
+        grid.Add(posBarSize_label, (2,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
+        grid.Add(self.posBarSize_slider, (2,1))
         grid.Add(gelHeight_label, (3,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         grid.Add(self.gelHeight_slider, (3,1))
         grid.Add(axisFontSize_label, (4,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
@@ -1249,7 +1247,7 @@ class dlgCanvasProperties(wx.Dialog):
         # get canvas params
         config.main['mzDigits'] = self.mzDigits_slider.GetValue()
         config.main['intDigits'] = self.intDigits_slider.GetValue()
-        config.spectrum['barHeight'] = self.barHeight_slider.GetValue()
+        config.spectrum['posBarSize'] = self.posBarSize_slider.GetValue()
         config.spectrum['gelHeight'] = self.gelHeight_slider.GetValue()
         config.spectrum['axisFontSize'] = self.axisFontSize_slider.GetValue()
         config.spectrum['labelFontSize'] = self.labelFontSize_slider.GetValue()
