@@ -471,10 +471,9 @@ class panelSpectrumGenerator(wx.MiniFrame):
         self.spectrumCanvas.setProperties(yLabel=config.spectrum['yLabel'])
         self.spectrumCanvas.setProperties(showGrid=config.spectrum['showGrid'])
         self.spectrumCanvas.setProperties(showMinorTicks=config.spectrum['showMinorTicks'])
-        self.spectrumCanvas.setProperties(showPosBar=config.spectrum['showPosBars'])
-        self.spectrumCanvas.setProperties(showIntBar=config.spectrum['showPosBars'])
-        self.spectrumCanvas.setProperties(posBarHeight=config.spectrum['barHeight'])
-        self.spectrumCanvas.setProperties(intBarHeight=config.spectrum['barHeight'])
+        self.spectrumCanvas.setProperties(showXPosBar=config.spectrum['showPosBars'])
+        self.spectrumCanvas.setProperties(showYPosBar=config.spectrum['showPosBars'])
+        self.spectrumCanvas.setProperties(posBarSize=config.spectrum['posBarSize'])
         self.spectrumCanvas.setProperties(showCurImage=config.spectrum['showCursorImage'])
         self.spectrumCanvas.setProperties(checkLimits=config.spectrum['checkLimits'])
         self.spectrumCanvas.setProperties(autoScaleY=config.spectrum['autoscale'])
