@@ -391,8 +391,8 @@ m_arrayd *signal_local_maxima( m_arrayd *p_signal )
     int i;
     
     // init buffer
-    size = (int) (p_signal->len/2);
-    if ( (p_buff = (double*) malloc( size*sizeof(double)) ) == NULL ) {
+    size = (int) (p_signal->len/2 + 1);
+    if ( (p_buff = (double*) malloc( 2*size*sizeof(double)) ) == NULL ) {
         return NULL;
     }
     
@@ -435,6 +435,9 @@ m_arrayd *signal_local_maxima( m_arrayd *p_signal )
         p_maxima->data[2*i+1] = p_buff[2*i+1];
     }
     
+    // free buffer
+    free(p_buff);
+    
     return p_maxima;
 }
 
@@ -1119,7 +1122,7 @@ m_arrayd *signal_filter( m_arrayd *p_signal, double resol )
 {
     m_arrayd *p_result;
     double *p_buff;
-    double currentX, currentY, lastX, lastY, previousX, previousY, minY, maxY;
+    double currentX, currentY, lastX, previousX, previousY, minY, maxY;
     int i, count;
     
     // init buffer
@@ -1131,7 +1134,7 @@ m_arrayd *signal_filter( m_arrayd *p_signal, double resol )
     p_buff[0] = p_signal->data[0];
     p_buff[1] = p_signal->data[1];
     lastX = previousX = p_signal->data[0];
-    lastY = minY = maxY = previousY = p_signal->data[1];
+    minY = maxY = previousY = p_signal->data[1];
     count = 1;
     
     // filter points
@@ -1170,7 +1173,7 @@ m_arrayd *signal_filter( m_arrayd *p_signal, double resol )
             ++count;
             
             lastX = previousX = currentX;
-            lastY = maxY = minY = previousY = currentY;
+            maxY = minY = previousY = currentY;
         }
         
         // if difference between current and previous x-values is lower
@@ -1707,6 +1710,10 @@ PyObject *list_mi2py( m_arrayi *p_inarr )
         }
     }
     
+    else {
+        p_outlist = PyList_New(0);
+    }
+    
     return p_outlist;
 }
 
