@@ -16,6 +16,7 @@
 # -------------------------------------------------------------------------
 
 # load libs
+import math
 import re
 
 # load stopper
@@ -117,6 +118,61 @@ def mz(mass, charge, currentCharge=0, agentFormula='H', agentCharge=1, massType=
 # ----
 
 
+def md(mass, mdType='standard', kendrickFormula='CH2', rounding='floor'):
+    """Calculate mass defect for given monoisotopic mass.
+        mass (float) - monoisotopic mass
+        mdType (fraction | standard | relative | kendrick) - mass defect type
+        kendrickFormula (str) - kendrick group formula
+        rounding (floor | ceil | round) - nominal mass rounding function
+    """
+    
+    # return fractional part
+    if mdType == 'fraction':
+        return mass - math.floor(mass)
+    
+    # return standard mass defect
+    elif mdType == 'standard':
+        return mass - nominalmass(mass, rounding)
+    
+    # return relative mass defect
+    elif mdType == 'relative':
+        return 1e6 * (mass - nominalmass(mass, rounding)) / mass
+    
+    # return Kendrick mass defect
+    elif mdType == 'kendrick':
+        
+        if not isinstance(kendrickFormula, obj_compound.compound):
+            kendrickFormula = obj_compound.compound(kendrickFormula)
+        
+        kendrickF = kendrickFormula.nominalmass()/kendrickFormula.mass(0)
+        
+        return  nominalmass(mass * kendrickF, rounding) - (mass * kendrickF)
+    
+    # unknown mass defect type
+    else: raise ValueError, 'Unknown mass defect type! --> ' + mdType
+# ----
+
+
+def nominalmass(mass, rounding='floor'):
+    """Calculate for given monoisotopic mass and rounding function.
+        mass (float) - monoisotopic mass
+        rounding (floor | ceil | round) - nominal mass rounding function
+    """
+    
+    if rounding == 'floor':
+        return math.floor(mass)
+    
+    elif rounding == 'ceil':
+        return math.ceil(mass)
+    
+    elif rounding == 'round':
+        return round(mass)
+    
+    # unknown rounding function
+    else: raise ValueError, 'Unknown nominal mass rounding! --> ' + rounding
+# ----
+
+
 
 # FORMULA FUNCTIONS
 # -----------------
