@@ -153,7 +153,7 @@ class sequence:
         for mod in parent.modifications:
             if mod[1] == 'nTerm' and start == 0:
                 peptide.modifications.append(mod)
-            elif mod[1] == 'cTerm' and (stop == -1 or stop == (len(parent)-1)):
+            elif mod[1] == 'cTerm' and (stop == -1 or stop == len(parent)):
                 peptide.modifications.append(mod)
             elif type(mod[1]) in (str, unicode) and mod[1] in peptide.chain:
                 peptide.modifications.append(mod)
