@@ -395,13 +395,13 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
             
             # total ion current
             elif paramName == 'total ion current' and paramValue != None:
-                self.data[self.currentID]['totIonCurrent'] = float(paramValue)
+                self.data[self.currentID]['totIonCurrent'] = max(0.0, float(paramValue))
             
             # base peak
             elif paramName == 'base peak m/z' and paramValue != None:
                 self.data[self.currentID]['basePeakMZ'] = float(paramValue)
             elif paramName == 'base peak intensity' and paramValue != None:
-                self.data[self.currentID]['basePeakIntensity'] = float(paramValue)
+                self.data[self.currentID]['basePeakIntensity'] = max(0.0, float(paramValue))
             
             # mass range
             elif paramName == 'lowest observed m/z' and paramValue != None:
@@ -413,8 +413,10 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
             elif paramName == 'scan start time' and paramValue != None:
                 if attrs.get('unitName','') == 'minute':
                     self.data[self.currentID]['retentionTime'] = float(paramValue)*60
-                if attrs.get('unitName','') == 'second':
+                elif attrs.get('unitName','') == 'second':
                     self.data[self.currentID]['retentionTime'] = float(paramValue)
+                else:
+                    self.data[self.currentID]['retentionTime'] = float(paramValue)*60
     # ----
     
     
@@ -587,13 +589,13 @@ class scanHandler(xml.sax.handler.ContentHandler):
             
             # total ion current
             elif paramName == 'total ion current' and paramValue != None:
-                self.data['totIonCurrent'] = float(paramValue)
+                self.data['totIonCurrent'] = max(0.0, float(paramValue))
             
             # base peak
             elif paramName == 'base peak m/z' and paramValue != None:
                 self.data['basePeakMZ'] = float(paramValue)
             elif paramName == 'base peak intensity' and paramValue != None:
-                self.data['basePeakIntensity'] = float(paramValue)
+                self.data['basePeakIntensity'] = max(0.0, float(paramValue))
             
             # mass range
             elif paramName == 'lowest observed m/z' and paramValue != None:
@@ -605,8 +607,10 @@ class scanHandler(xml.sax.handler.ContentHandler):
             elif paramName == 'scan start time' and paramValue != None:
                 if attrs.get('unitName','') == 'minute':
                     self.data['retentionTime'] = float(paramValue)*60
-                if attrs.get('unitName','') == 'second':
+                elif attrs.get('unitName','') == 'second':
                     self.data['retentionTime'] = float(paramValue)
+                else:
+                    self.data['retentionTime'] = float(paramValue)*60
     # ----
     
     
@@ -808,13 +812,13 @@ class runHandler(xml.sax.handler.ContentHandler):
             
             # total ion current
             elif paramName == 'total ion current' and paramValue != None:
-                self.data[self.currentID]['totIonCurrent'] = float(paramValue)
+                self.data[self.currentID]['totIonCurrent'] = max(0.0, float(paramValue))
             
             # base peak
             elif paramName == 'base peak m/z' and paramValue != None:
                 self.data[self.currentID]['basePeakMZ'] = float(paramValue)
             elif paramName == 'base peak intensity' and paramValue != None:
-                self.data[self.currentID]['basePeakIntensity'] = float(paramValue)
+                self.data[self.currentID]['basePeakIntensity'] = max(0.0, float(paramValue))
             
             # mass range
             elif paramName == 'lowest observed m/z' and paramValue != None:
@@ -826,8 +830,10 @@ class runHandler(xml.sax.handler.ContentHandler):
             elif paramName == 'scan start time' and paramValue != None:
                 if attrs.get('unitName','') == 'minute':
                     self.data[self.currentID]['retentionTime'] = float(paramValue)*60
-                if attrs.get('unitName','') == 'second':
+                elif attrs.get('unitName','') == 'second':
                     self.data[self.currentID]['retentionTime'] = float(paramValue)
+                else:
+                    self.data[self.currentID]['retentionTime'] = float(paramValue)*60
     # ----
     
     
@@ -846,7 +852,7 @@ class runHandler(xml.sax.handler.ContentHandler):
             self._isPrecursor = False
         
         # stop reading peaks data
-        elif name == 'binaryDataArray':
+        elif name == 'binaryDataArray' and self._isSpectrum:
             self._isBinaryDataArray = False
             
             # mz array
@@ -1023,13 +1029,13 @@ class singleScanParser():
             
             # total ion current
             elif paramName == 'total ion current' and paramValue:
-                self.data['totIonCurrent'] = float(paramValue)
+                self.data['totIonCurrent'] = max(0.0, float(paramValue))
             
             # base peak
             elif paramName == 'base peak m/z' and paramValue:
                 self.data['basePeakMZ'] = float(paramValue)
             elif paramName == 'base peak intensity' and paramValue:
-                self.data['basePeakIntensity'] = float(paramValue)
+                self.data['basePeakIntensity'] = max(0.0, float(paramValue))
             
             # mass range
             elif paramName == 'lowest observed m/z' and paramValue:
@@ -1041,8 +1047,10 @@ class singleScanParser():
             elif paramName == 'scan start time' and paramValue:
                 if cvParamTag.getAttribute('unitName') == 'minute':
                     self.data['retentionTime'] = float(paramValue)*60
-                if cvParamTag.getAttribute('unitName') == 'second':
+                elif cvParamTag.getAttribute('unitName') == 'second':
                     self.data['retentionTime'] = float(paramValue)
+                else:
+                    self.data['retentionTime'] = float(paramValue)*60
     # ----
     
     
