@@ -378,12 +378,12 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
             # get base peak intensity
             attribute = attrs.get('basePeakIntensity', None)
             if attribute != None:
-                scan['basePeakIntensity'] = float(attribute)
+                scan['basePeakIntensity'] = max(0.0, float(attribute))
             
             # get total ion current
             attribute = attrs.get('totIonCurrent', None)
             if attribute != None:
-                scan['totIonCurrent'] = float(attribute)
+                scan['totIonCurrent'] = max(0.0, float(attribute))
             
             # add scan
             self.data[self.currentID] = scan
@@ -396,7 +396,7 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
             # get precursor intensity
             attribute = attrs.get('precursorIntensity', None)
             if attribute != None:
-                self.data[self.currentID]['precursorIntensity'] = float(attribute)
+                self.data[self.currentID]['precursorIntensity'] = max(0.0, float(attribute))
             
             # get precursor charge
             attribute = attrs.get('precursorCharge', None)
@@ -539,12 +539,12 @@ class scanHandler(xml.sax.handler.ContentHandler):
                 # get base peak intensity
                 attribute = attrs.get('basePeakIntensity', None)
                 if attribute != None:
-                    self.data['basePeakIntensity'] = float(attribute)
+                    self.data['basePeakIntensity'] = max(0.0, float(attribute))
                 
                 # get total ion current
                 attribute = attrs.get('totIonCurrent', None)
                 if attribute != None:
-                    self.data['totIonCurrent'] = float(attribute)
+                    self.data['totIonCurrent'] = max(0.0, float(attribute))
         
         # get peaks data
         elif name == 'peaks' and self._isMatch:
@@ -572,7 +572,7 @@ class scanHandler(xml.sax.handler.ContentHandler):
             # get precursor intensity
             attribute = attrs.get('precursorIntensity', None)
             if attribute != None:
-                self.data['precursorIntensity'] = float(attribute)
+                self.data['precursorIntensity'] = max(0.0, float(attribute))
             
             # get precursor charge
             attribute = attrs.get('precursorCharge', None)
@@ -724,12 +724,12 @@ class runHandler(xml.sax.handler.ContentHandler):
             # get base peak intensity
             attribute = attrs.get('basePeakIntensity', None)
             if attribute != None:
-                scan['basePeakIntensity'] = float(attribute)
+                scan['basePeakIntensity'] = max(0.0, float(attribute))
             
             # get total ion current
             attribute = attrs.get('totIonCurrent', None)
             if attribute != None:
-                scan['totIonCurrent'] = float(attribute)
+                scan['totIonCurrent'] = max(0.0, float(attribute))
             
             # add scan
             self.data[self.currentID] = scan
@@ -760,7 +760,7 @@ class runHandler(xml.sax.handler.ContentHandler):
             # get precursor intensity
             attribute = attrs.get('precursorIntensity', None)
             if attribute != None:
-                self.data[self.currentID]['precursorIntensity'] = float(attribute)
+                self.data[self.currentID]['precursorIntensity'] = max(0.0, float(attribute))
             
             # get precursor charge
             attribute = attrs.get('precursorCharge', None)
@@ -946,12 +946,12 @@ class singleScanParser():
             # get base peak intensity
             attribute = scanTags[0].getAttribute('basePeakIntensity')
             if attribute:
-                self.data['basePeakIntensity'] = float(attribute)
+                self.data['basePeakIntensity'] = max(0.0, float(attribute))
             
             # get total ion current
             attribute = scanTags[0].getAttribute('totIonCurrent')
             if attribute:
-                self.data['totIonCurrent'] = float(attribute)
+                self.data['totIonCurrent'] = max(0.0, float(attribute))
         
         # get precursor
         precursorMzTags = self._parsedData.getElementsByTagName('precursorMz')
@@ -960,7 +960,7 @@ class singleScanParser():
             # get precursor intensity
             attribute = precursorMzTags[0].getAttribute('precursorIntensity')
             if attribute:
-                self.data['precursorIntensity'] = float(attribute)
+                self.data['precursorIntensity'] = max(0.0, float(attribute))
             
             # get precursor charge
             attribute = precursorMzTags[0].getAttribute('precursorCharge')
