@@ -23,17 +23,11 @@ import numpy
 # MAIN PLOT CANVAS OBJECT
 # -----------------------
 
-class canvas(wx.Panel):
+class canvas(wx.Window):
     """Plot canvas"""
     
     def __init__(self, parent, id=-1, size=wx.DefaultSize, style=wx.DEFAULT_FRAME_STYLE, **attr):
-        wx.Panel.__init__(self, parent, id, size=size, style=style)
-        
-        # make canvas window
-        self.canvas = wx.Window(self, -1, size=size)
-        sizer = wx.BoxSizer(wx.HORIZONTAL)
-        sizer.Add(self.canvas, 1, wx.EXPAND)
-        self.SetSizer(sizer)
+        wx.Window.__init__(self, parent, id, size=size, style=style)
         
         self.parent = parent
         self.SetBackgroundColour('white')
@@ -47,8 +41,8 @@ class canvas(wx.Panel):
             'showMinorTicks': True,
             'showZero': False,
             'showLegend': False,
-            'showPosBar': False,
-            'showIntBar': False,
+            'showXPosBar': False,
+            'showYPosBar': False,
             'showGel': False,
             'showCurXPos': True,
             'showCurYPos': True,
@@ -58,8 +52,7 @@ class canvas(wx.Panel):
             'autoScaleY': True,
             'ySymmetry': False,
             'overlapLabels': True,
-            'posBarHeight': 10,
-            'intBarHeight': 10,
+            'posBarSize': 6,
             'gelHeight': 13,
             'xPosDigits': 2,
             'yPosDigits': 0,
@@ -108,20 +101,20 @@ class canvas(wx.Panel):
         self.pointShift = 0
         
         # set events
-        self.canvas.Bind(wx.EVT_PAINT, self.onPaint)
-        self.canvas.Bind(wx.EVT_SIZE, self.onSize)
-        self.canvas.Bind(wx.EVT_LEAVE_WINDOW, self.onLeave)
-        self.canvas.Bind(wx.EVT_LEFT_DOWN, self.onLMD)
-        self.canvas.Bind(wx.EVT_LEFT_UP, self.onLMU)
-        self.canvas.Bind(wx.EVT_LEFT_DCLICK, self.onLMDC)
-        self.canvas.Bind(wx.EVT_RIGHT_DOWN, self.onRMD)
-        self.canvas.Bind(wx.EVT_RIGHT_UP, self.onRMU)
-        self.canvas.Bind(wx.EVT_RIGHT_DCLICK, self.onRMDC)
-        self.canvas.Bind(wx.EVT_MIDDLE_DOWN, self.onRMD)
-        self.canvas.Bind(wx.EVT_MIDDLE_UP, self.onRMU)
-        self.canvas.Bind(wx.EVT_MOTION, self.onMMotion)
-        self.canvas.Bind(wx.EVT_MOUSEWHEEL, self.onMScroll)
-        self.canvas.Bind(wx.EVT_KEY_DOWN, self.onChar)
+        self.Bind(wx.EVT_PAINT, self.onPaint)
+        self.Bind(wx.EVT_SIZE, self.onSize)
+        self.Bind(wx.EVT_LEAVE_WINDOW, self.onLeave)
+        self.Bind(wx.EVT_LEFT_DOWN, self.onLMD)
+        self.Bind(wx.EVT_LEFT_UP, self.onLMU)
+        self.Bind(wx.EVT_LEFT_DCLICK, self.onLMDC)
+        self.Bind(wx.EVT_RIGHT_DOWN, self.onRMD)
+        self.Bind(wx.EVT_RIGHT_UP, self.onRMU)
+        self.Bind(wx.EVT_RIGHT_DCLICK, self.onRMDC)
+        self.Bind(wx.EVT_MIDDLE_DOWN, self.onRMD)
+        self.Bind(wx.EVT_MIDDLE_UP, self.onRMU)
+        self.Bind(wx.EVT_MOTION, self.onMMotion)
+        self.Bind(wx.EVT_MOUSEWHEEL, self.onMScroll)
+        self.Bind(wx.EVT_KEY_DOWN, self.onChar)
         
         # initialize bitmap buffer and set initial size based on client size
         self.onSize(0)
@@ -136,7 +129,7 @@ class canvas(wx.Panel):
             self.drawMouseTracker()
         
         # draw buffer to screen
-        dc = wx.BufferedPaintDC(self.canvas, self.plotBuffer)
+        dc = wx.BufferedPaintDC(self, self.plotBuffer)
     # ----
     
     
@@ -144,7 +137,7 @@ class canvas(wx.Panel):
         """Repaint plot when size changed."""
         
         # get size
-        width, height = self.canvas.GetClientSize()
+        width, height = self.GetClientSize()
         width = max(1, width)
         height = max(1, height)
             
@@ -187,7 +180,7 @@ class canvas(wx.Panel):
         self.escMouseEvents()
         
         # set mouse cursor
-        self.canvas.SetCursor(wx.StockCursor(wx.CURSOR_ARROW))
+        self.SetCursor(wx.StockCursor(wx.CURSOR_ARROW))
     # ----
     
     
@@ -195,8 +188,8 @@ class canvas(wx.Panel):
         """Change cursor style according to position and current mouse function."""
         
         # get focus
-        if not self.FindFocus() == self.canvas:
-            self.canvas.SetFocus()
+        if not self.FindFocus() == self:
+            self.SetFocus()
             try: wx.Yield()
             except: pass
         
@@ -262,8 +255,8 @@ class canvas(wx.Panel):
         """Clear cursor."""
         
         # get focus
-        if not self.FindFocus() == self.canvas:
-            self.canvas.SetFocus()
+        if not self.FindFocus() == self:
+            self.SetFocus()
             return
         
         # zoom plot
@@ -357,8 +350,8 @@ class canvas(wx.Panel):
         """Change cursor style according to position and current mouse function."""
         
         # get focus
-        if not self.FindFocus() == self.canvas:
-            self.canvas.SetFocus()
+        if not self.FindFocus() == self:
+            self.SetFocus()
             
         # get cursor positions
         self.cursorPosition[0], self.cursorPosition[1] = self.getXY(evt)
@@ -395,8 +388,8 @@ class canvas(wx.Panel):
         """Set new zoom and clear cursor."""
         
         # get focus
-        if not self.FindFocus() == self.canvas:
-            self.canvas.SetFocus()
+        if not self.FindFocus() == self:
+            self.SetFocus()
             return
             
         # zoom dragging
@@ -799,7 +792,7 @@ class canvas(wx.Panel):
         
         # get width/height if not set
         if not width or not height:
-            width, height = self.canvas.GetClientSize()
+            width, height = self.GetClientSize()
         
         # create empty bitmap
         tmpBitmap = wx.EmptyBitmap(width, height)
@@ -996,7 +989,7 @@ class canvas(wx.Panel):
         
         # get size
         if width == None:
-            (width, height) = self.canvas.GetClientSize()
+            (width, height) = self.GetClientSize()
         
         # set size
         self.plotBoxSize = numpy.array([width, height])
@@ -1057,15 +1050,15 @@ class canvas(wx.Panel):
         
         location = self.getCursorLocation()
         if location == 'xAxis':
-            self.canvas.SetCursor(wx.StockCursor(wx.CURSOR_SIZEWE))
+            self.SetCursor(wx.StockCursor(wx.CURSOR_SIZEWE))
         elif location == 'yAxis':
-            self.canvas.SetCursor(wx.StockCursor(wx.CURSOR_SIZENS))
+            self.SetCursor(wx.StockCursor(wx.CURSOR_SIZENS))
         elif location == 'plot' and self.properties['showCurImage']:
-            self.canvas.SetCursor(self.cursorImage)
+            self.SetCursor(self.cursorImage)
         elif location == 'plot' and self.mouseFn:
-            self.canvas.SetCursor(wx.StockCursor(wx.CURSOR_CROSS))
+            self.SetCursor(wx.StockCursor(wx.CURSOR_CROSS))
         else:
-            self.canvas.SetCursor(wx.StockCursor(wx.CURSOR_ARROW))
+            self.SetCursor(wx.StockCursor(wx.CURSOR_ARROW))
     # ----
     
     
@@ -1077,7 +1070,7 @@ class canvas(wx.Panel):
         
         # set DC
         if dc == None:
-            dc = wx.BufferedDC(wx.ClientDC(self.canvas), self.plotBuffer)
+            dc = wx.BufferedDC(wx.ClientDC(self), self.plotBuffer)
         dc.SetBackground(wx.Brush(self.properties['canvasColour'], wx.SOLID))
         dc.Clear()
         dc.BeginDrawing()
@@ -1124,15 +1117,15 @@ class canvas(wx.Panel):
         spaceBottom = xAxisTextExtent[1] + xAxisLabelWH[1] + 10*self.printerScale['drawings']
         
         spaceTop = 15
-        if self.properties['showPosBar']:
-            spaceTop += self.properties['posBarHeight'] + 6
+        if self.properties['showXPosBar']:
+            spaceTop += self.properties['posBarSize'] + 6
         if self.properties['showGel']:
             spaceTop += self.gelsCount * self.properties['gelHeight'] + 6 + 2
         spaceTop = spaceTop * self.printerScale['drawings']
         
         spaceRight = xAxisTextExtent[0]/1.5
-        if self.properties['showIntBar']:
-            spaceRight = max(xAxisTextExtent[0]/1.5, (self.properties['intBarHeight'] + 6 + 8) * self.printerScale['drawings'])
+        if self.properties['showYPosBar']:
+            spaceRight = max(xAxisTextExtent[0]/1.5, (self.properties['posBarSize'] + 6 + 8) * self.printerScale['drawings'])
         
         # get scaling and shifting
         textSizeScale = numpy.array([spaceRight + spaceLeft, spaceBottom + spaceTop])
@@ -1160,13 +1153,13 @@ class canvas(wx.Panel):
         # draw plot axis
         self.drawAxis(dc, xAxisTicks, yAxisTicks)
         
-        # draw plot position box
-        if self.properties['showPosBar']:
-            self.drawPositionBar(dc, xAxis)
+        # draw plot x position box
+        if self.properties['showXPosBar']:
+            self.drawXPositionBar(dc, xAxis)
         
-        # draw intensity position box
-        if self.properties['showIntBar']:
-            self.drawIntensityBar(dc, yAxis)
+        # draw plot y position box
+        if self.properties['showYPosBar']:
+            self.drawYPositionBar(dc, yAxis)
         
         # draw gel
         if self.properties['showGel']:
@@ -1313,7 +1306,7 @@ class canvas(wx.Panel):
     # ----
     
     
-    def drawPositionBar(self, dc, xAxis):
+    def drawXPositionBar(self, dc, xAxis):
         """Draw position bar."""
         
         # set pen
@@ -1326,7 +1319,7 @@ class canvas(wx.Panel):
         y1 = 14 * self.printerScale['drawings']
         x2 += self.printerScale['drawings']
         width = x2 - x1
-        height = self.properties['posBarHeight'] * self.printerScale['drawings']
+        height = self.properties['posBarSize'] * self.printerScale['drawings']
         
         # get current position
         minX, maxX = self.getMaxXRange(absolute=True)
@@ -1364,7 +1357,7 @@ class canvas(wx.Panel):
     # ----
     
     
-    def drawIntensityBar(self, dc, yAxis):
+    def drawYPositionBar(self, dc, yAxis):
         """Draw position bar."""
         
         # set pen
@@ -1377,7 +1370,7 @@ class canvas(wx.Panel):
         y1 -= self.printerScale['drawings'] 
         y2 += self.printerScale['drawings'] 
         height = y2 - y1
-        width = self.properties['intBarHeight'] * self.printerScale['drawings']
+        width = self.properties['posBarSize'] * self.printerScale['drawings']
         
         # get current position
         minY, maxY = self.getMaxYRange(absolute=True)
@@ -1503,7 +1496,7 @@ class canvas(wx.Panel):
             maxYGel += 1
         
         # draw tracker lines
-        dc = wx.ClientDC(self.canvas)
+        dc = wx.ClientDC(self)
         dc.BeginDrawing()
         dc.SetPen(wx.Pen(wx.BLACK))
         dc.SetLogicalFunction(wx.INVERT)
@@ -1563,7 +1556,7 @@ class canvas(wx.Panel):
             return
         
         # hide cursor
-        self.canvas.SetCursor(wx.StockCursor(wx.CURSOR_BLANK))
+        self.SetCursor(wx.StockCursor(wx.CURSOR_BLANK))
         
         # get screen coordinations
         x1 = self.draggingStart[2]
@@ -1587,7 +1580,7 @@ class canvas(wx.Panel):
             maxY -= 1
         
         # draw tracker
-        dc = wx.ClientDC(self.canvas)
+        dc = wx.ClientDC(self)
         dc.BeginDrawing()
         dc.SetLogicalFunction(wx.INVERT)
         dc.SetPen(wx.Pen(wx.BLACK))
@@ -1654,7 +1647,7 @@ class canvas(wx.Panel):
             return
         
         # hide cursor
-        self.canvas.SetCursor(wx.StockCursor(wx.CURSOR_BLANK))
+        self.SetCursor(wx.StockCursor(wx.CURSOR_BLANK))
         
         # get X coordinations
         x = self.cursorPosition[2]
@@ -1666,7 +1659,7 @@ class canvas(wx.Panel):
         currentY = self.getPoint(x, coord='screen')
         
         # draw tracker lines
-        dc = wx.ClientDC(self.canvas)
+        dc = wx.ClientDC(self)
         dc.BeginDrawing()
         dc.SetPen(wx.Pen(wx.BLACK))
         dc.SetLogicalFunction(wx.INVERT)
@@ -1760,7 +1753,7 @@ class canvas(wx.Panel):
             mz += diff
         
         # set pen
-        dc = wx.ClientDC(self.canvas)
+        dc = wx.ClientDC(self)
         dc.BeginDrawing()
         dc.SetLogicalFunction(wx.INVERT)
         dc.SetPen(wx.Pen(wx.BLACK))
@@ -1826,7 +1819,7 @@ class canvas(wx.Panel):
             maxX = self.plotCoords[2]
         
         # draw zoombox
-        dc = wx.ClientDC(self.canvas)
+        dc = wx.ClientDC(self)
         dc.BeginDrawing()
         dc.SetPen(wx.Pen(wx.BLACK))
         dc.SetBrush(wx.Brush(wx.WHITE, wx.SOLID))
@@ -1876,7 +1869,7 @@ class canvas(wx.Panel):
             maxYGel = minYGel - self.gelsCount * self.properties['gelHeight']
         
         # set canvas and pen
-        dc = wx.ClientDC(self.canvas)
+        dc = wx.ClientDC(self)
         dc.BeginDrawing()
         dc.SetPen(wx.Pen(wx.BLACK))
         dc.SetBrush(wx.Brush(wx.WHITE, wx.SOLID))
@@ -1930,7 +1923,7 @@ class canvas(wx.Panel):
         height = y2 - y1
         
         # draw tracker lines
-        dc = wx.ClientDC(self.canvas)
+        dc = wx.ClientDC(self)
         dc.BeginDrawing()
         dc.SetLogicalFunction(wx.INVERT)
         dc.SetPen(wx.Pen(wx.BLACK))
@@ -1959,7 +1952,7 @@ class canvas(wx.Panel):
             x1, x2 = x2, x1
         
         # draw tracker lines
-        dc = wx.ClientDC(self.canvas)
+        dc = wx.ClientDC(self)
         dc.BeginDrawing()
         dc.SetLogicalFunction(wx.INVERT)
         dc.SetPen(wx.Pen(wx.BLACK))
@@ -1992,7 +1985,7 @@ class canvas(wx.Panel):
         y += 1
         
         # set dc
-        dc = wx.BufferedDC(wx.ClientDC(self.canvas), self.plotBuffer)
+        dc = wx.BufferedDC(wx.ClientDC(self), self.plotBuffer)
         dc.SetPen(wx.TRANSPARENT_PEN)
         dc.SetBrush(wx.Brush(self.properties['highlightColour'], wx.SOLID))
         
@@ -2088,7 +2081,7 @@ class canvas(wx.Panel):
     def clear(self):
         """Clear plot window"""
         
-        dc = wx.BufferedDC(wx.ClientDC(self.canvas), self.plotBuffer)
+        dc = wx.BufferedDC(wx.ClientDC(self), self.plotBuffer)
         dc.Clear()
         self.lastDraw = None
     # ----
