@@ -72,7 +72,10 @@ class container:
         for obj in self.objects:
             if obj.properties['visible']:
                 oRect = obj.getBoundingBox(minX, maxX, absolute)
-                if have and oRect:
+                
+                if not oRect or not numpy.all(numpy.isfinite(oRect)):
+                    continue
+                elif have and oRect:
                     rect[0] = numpy.minimum(rect[0], oRect[0])
                     rect[1] = numpy.maximum(rect[1], oRect[1])
                 elif oRect:
